"use client"

import type React from "react"

import { useState } from "react"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Input } from "@/components/ui/input"
import { Label } from "@/components/ui/label"
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs"
import { useToast } from "@/components/ui/use-toast"
import { Alert, AlertDescription, AlertTitle } from "@/components/ui/alert"

export default function FirmaDigitalPage() {
  const { toast } = useToast()

  const [firmaConfig, setFirmaConfig] = useState({
    tipoFirma: "imagen", // "imagen" o "criptografica"
    imagenFirma: null as File | null,
    certificadoDigital: null as File | null,
    clavePrivada: "",
    configurada: false,
  })

  const [previewFirma, setPreviewFirma] = useState<string | null>(null)

  const handleImagenFirma = (e: React.ChangeEvent<HTMLInputElement>) => {
    const file = e.target.files?.[0]
    if (file) {
      setFirmaConfig({ ...firmaConfig, imagenFirma: file })

      // Crear preview de la imagen
      const reader = new FileReader()
      reader.onload = (e) => {
        setPreviewFirma(e.target?.result as string)
      }
      reader.readAsDataURL(file)
    }
  }

  const handleGuardarFirmaImagen = () => {
    if (!firmaConfig.imagenFirma) {
      toast({
        title: "Error",
        description: "Por favor seleccione una imagen de firma.",
        variant: "destructive",
      })
      return
    }

    setFirmaConfig({ ...firmaConfig, configurada: true })
    toast({
      title: "Firma configurada",
      description: "Su firma por imagen ha sido configurada exitosamente.",
    })
  }

  const handleGuardarFirmaCriptografica = () => {
    if (!firmaConfig.certificadoDigital || !firmaConfig.clavePrivada) {
      toast({
        title: "Error",
        description: "Por favor complete todos los campos requeridos.",
        variant: "destructive",
      })
      return
    }

    setFirmaConfig({ ...firmaConfig, configurada: true })
    toast({
      title: "Firma criptográfica configurada",
      description: "Su firma digital criptográfica ha sido configurada exitosamente.",
    })
  }

  const handleGenerarCertificado = () => {
    // Simulación de generación de certificado con OpenSSL
    toast({
      title: "Certificado generado",
      description: "Se ha generado un nuevo par de claves y certificado digital.",
    })
  }

  return (
    <div className="space-y-6">
      <div className="flex flex-col md:flex-row md:items-center md:justify-between gap-4">
        <div>
          <h1 className="text-3xl font-bold tracking-tight">Configuración de Firma Digital</h1>
          <p className="text-muted-foreground">Configure su firma digital para documentos oficiales</p>
        </div>
        {firmaConfig.configurada && (
          <div className="flex items-center gap-2 text-green-700">
            <svg
              xmlns="http://www.w3.org/2000/svg"
              width="20"
              height="20"
              viewBox="0 0 24 24"
              fill="none"
              stroke="currentColor"
              strokeWidth="2"
              strokeLinecap="round"
              strokeLinejoin="round"
            >
              <path d="M22 11.08V12a10 10 0 1 1-5.93-9.14" />
              <polyline points="22 4 12 14.01 9 11.01" />
            </svg>
            <span className="font-medium">Firma Configurada</span>
          </div>
        )}
      </div>

      <Tabs defaultValue="imagen" className="space-y-4">
        <TabsList>
          <TabsTrigger value="imagen">Firma por Imagen</TabsTrigger>
          <TabsTrigger value="criptografica">Firma Criptográfica</TabsTrigger>
          <TabsTrigger value="documentos">Documentos Pendientes</TabsTrigger>
        </TabsList>

        <TabsContent value="imagen">
          <Card>
            <CardHeader>
              <CardTitle>Configurar Firma por Imagen</CardTitle>
              <CardDescription>
                Suba una imagen escaneada de su firma manuscrita para usar en los documentos
              </CardDescription>
            </CardHeader>
            <CardContent className="space-y-6">
              <Alert>
                <svg
                  xmlns="http://www.w3.org/2000/svg"
                  width="16"
                  height="16"
                  viewBox="0 0 24 24"
                  fill="none"
                  stroke="currentColor"
                  strokeWidth="2"
                  strokeLinecap="round"
                  strokeLinejoin="round"
                >
                  <circle cx="12" cy="12" r="10" />
                  <path d="m9 12 2 2 4-4" />
                </svg>
                <AlertTitle>Recomendaciones para la imagen de firma</AlertTitle>
                <AlertDescription>
                  • Use una imagen con fondo transparente o blanco
                  <br />• Resolución mínima: 300 DPI
                  <br />• Formato recomendado: PNG o JPG
                  <br />• Tamaño máximo: 2MB
                </AlertDescription>
              </Alert>

              <div className="space-y-4">
                <div>
                  <Label htmlFor="imagenFirma">Imagen de Firma</Label>
                  <Input id="imagenFirma" type="file" accept="image/*" onChange={handleImagenFirma} className="mt-1" />
                </div>

                {previewFirma && (
                  <div className="border rounded-lg p-4">
                    <Label className="text-sm font-medium">Vista Previa:</Label>
                    <div className="mt-2 bg-gray-50 p-4 rounded border-2 border-dashed">
                      <img
                        src={previewFirma || "/placeholder.svg"}
                        alt="Vista previa de firma"
                        className="max-h-32 mx-auto"
                      />
                    </div>
                  </div>
                )}

                <Button
                  onClick={handleGuardarFirmaImagen}
                  className="bg-red-700 hover:bg-red-800"
                  disabled={!firmaConfig.imagenFirma}
                >
                  Guardar Configuración
                </Button>
              </div>
            </CardContent>
          </Card>
        </TabsContent>

        <TabsContent value="criptografica">
          <Card>
            <CardHeader>
              <CardTitle>Configurar Firma Criptográfica</CardTitle>
              <CardDescription>Configure una firma digital criptográfica usando certificados digitales</CardDescription>
            </CardHeader>
            <CardContent className="space-y-6">
              <Alert>
                <svg
                  xmlns="http://www.w3.org/2000/svg"
                  width="16"
                  height="16"
                  viewBox="0 0 24 24"
                  fill="none"
                  stroke="currentColor"
                  strokeWidth="2"
                  strokeLinecap="round"
                  strokeLinejoin="round"
                >
                  <path d="M9 12l2 2 4-4" />
                  <path d="M21 12c.552 0 1-.448 1-1s-.448-1-1-1-1 .448-1 1 .448 1 1 1" />
                  <path d="M3 12c.552 0 1-.448 1-1s-.448-1-1-1-1 .448-1 1 .448 1 1 1" />
                  <path d="M12 21c.552 0 1-.448 1-1s-.448-1-1-1-1 .448-1 1 .448 1 1 1" />
                  <path d="M12 3c.552 0 1-.448 1-1s-.448-1-1-1-1 .448-1 1 .448 1 1 1" />
                </svg>
                <AlertTitle>Firma Digital Segura</AlertTitle>
                <AlertDescription>
                  La firma criptográfica utiliza OpenSSL para garantizar la autenticidad e integridad de los documentos.
                </AlertDescription>
              </Alert>

              <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                <div className="space-y-4">
                  <h3 className="text-lg font-semibold">Opción 1: Subir Certificado Existente</h3>

                  <div>
                    <Label htmlFor="certificadoDigital">Certificado Digital (.p12 o .pfx)</Label>
                    <Input
                      id="certificadoDigital"
                      type="file"
                      accept=".p12,.pfx"
                      onChange={(e) =>
                        setFirmaConfig({
                          ...firmaConfig,
                          certificadoDigital: e.target.files?.[0] || null,
                        })
                      }
                      className="mt-1"
                    />
                  </div>

                  <div>
                    <Label htmlFor="clavePrivada">Contraseña del Certificado</Label>
                    <Input
                      id="clavePrivada"
                      type="password"
                      value={firmaConfig.clavePrivada}
                      onChange={(e) =>
                        setFirmaConfig({
                          ...firmaConfig,
                          clavePrivada: e.target.value,
                        })
                      }
                      placeholder="Ingrese la contraseña del certificado"
                    />
                  </div>

                  <Button onClick={handleGuardarFirmaCriptografica} className="bg-red-700 hover:bg-red-800 w-full">
                    Configurar Firma Criptográfica
                  </Button>
                </div>

                <div className="space-y-4">
                  <h3 className="text-lg font-semibold">Opción 2: Generar Nuevo Certificado</h3>

                  <div className="bg-blue-50 p-4 rounded-lg">
                    <p className="text-sm text-blue-800 mb-3">
                      Genere un nuevo par de claves y certificado digital para firma.
                    </p>
                    <Button onClick={handleGenerarCertificado} variant="outline" className="w-full">
                      <svg
                        xmlns="http://www.w3.org/2000/svg"
                        width="16"
                        height="16"
                        viewBox="0 0 24 24"
                        fill="none"
                        stroke="currentColor"
                        strokeWidth="2"
                        strokeLinecap="round"
                        strokeLinejoin="round"
                        className="mr-2"
                      >
                        <path d="M9 12l2 2 4-4" />
                        <path d="M21 12c.552 0 1-.448 1-1s-.448-1-1-1-1 .448-1 1 .448 1 1 1" />
                        <path d="M3 12c.552 0 1-.448 1-1s-.448-1-1-1-1 .448-1 1 .448 1 1 1" />
                        <path d="M12 21c.552 0 1-.448 1-1s-.448-1-1-1-1 .448-1 1 .448 1 1 1" />
                        <path d="M12 3c.552 0 1-.448 1-1s-.448-1-1-1-1 .448-1 1 .448 1 1 1" />
                      </svg>
                      Generar Certificado
                    </Button>
                  </div>

                  <div className="text-sm text-muted-foreground">
                    <h4 className="font-medium mb-2">Información técnica:</h4>
                    <ul className="space-y-1">
                      <li>• Algoritmo: RSA 2048 bits</li>
                      <li>• Hash: SHA-256</li>
                      <li>• Validez: 2 años</li>
                      <li>• Estándar: X.509</li>
                    </ul>
                  </div>
                </div>
              </div>
            </CardContent>
          </Card>
        </TabsContent>

        <TabsContent value="documentos">
          <Card>
            <CardHeader>
              <CardTitle>Documentos Pendientes de Firma</CardTitle>
              <CardDescription>Documentos que requieren su firma digital</CardDescription>
            </CardHeader>
            <CardContent>
              <div className="space-y-4">
                {[
                  {
                    id: 1,
                    tipo: "Certificado",
                    participante: "Carlos Andrés Pérez",
                    curso: "Técnicas de Rescate en Estructuras Colapsadas",
                    fecha: "2023-06-15",
                  },
                  {
                    id: 2,
                    tipo: "Acta de Calificaciones",
                    participante: "Múltiples participantes",
                    curso: "Primeros Auxilios Avanzados",
                    fecha: "2023-06-10",
                  },
                  {
                    id: 3,
                    tipo: "Certificado",
                    participante: "María Elena Rodríguez",
                    curso: "Manejo de Materiales Peligrosos",
                    fecha: "2023-06-08",
                  },
                ].map((documento) => (
                  <div key={documento.id} className="flex items-center justify-between border rounded-lg p-4">
                    <div className="flex items-center gap-4">
                      <div className="bg-red-100 p-2 rounded-full">
                        <svg
                          xmlns="http://www.w3.org/2000/svg"
                          width="20"
                          height="20"
                          viewBox="0 0 24 24"
                          fill="none"
                          stroke="currentColor"
                          strokeWidth="2"
                          strokeLinecap="round"
                          strokeLinejoin="round"
                          className="text-red-700"
                        >
                          <path d="M14.5 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7.5L14.5 2z" />
                          <polyline points="14 2 14 8 20 8" />
                        </svg>
                      </div>
                      <div>
                        <h3 className="font-semibold">{documento.tipo}</h3>
                        <p className="text-sm text-muted-foreground">{documento.participante}</p>
                        <p className="text-sm text-muted-foreground">{documento.curso}</p>
                        <p className="text-xs text-muted-foreground">Fecha: {documento.fecha}</p>
                      </div>
                    </div>
                    <div className="flex gap-2">
                      <Button variant="outline" size="sm">
                        <svg
                          xmlns="http://www.w3.org/2000/svg"
                          width="16"
                          height="16"
                          viewBox="0 0 24 24"
                          fill="none"
                          stroke="currentColor"
                          strokeWidth="2"
                          strokeLinecap="round"
                          strokeLinejoin="round"
                          className="mr-2"
                        >
                          <path d="M2 12s3-7 10-7 10 7 10 7-3 7-10 7-10-7-10-7Z" />
                          <circle cx="12" cy="12" r="3" />
                        </svg>
                        Ver
                      </Button>
                      <Button size="sm" className="bg-red-700 hover:bg-red-800" disabled={!firmaConfig.configurada}>
                        <svg
                          xmlns="http://www.w3.org/2000/svg"
                          width="16"
                          height="16"
                          viewBox="0 0 24 24"
                          fill="none"
                          stroke="currentColor"
                          strokeWidth="2"
                          strokeLinecap="round"
                          strokeLinejoin="round"
                          className="mr-2"
                        >
                          <path d="m12 19 7-7 3 3-7 7-3-3z" />
                          <path d="m18 13-1.5-7.5L2 2l3.5 14.5L13 18l5-5z" />
                          <path d="m2 2 7.586 7.586" />
                          <circle cx="11" cy="11" r="2" />
                        </svg>
                        Firmar
                      </Button>
                    </div>
                  </div>
                ))}
              </div>

              {!firmaConfig.configurada && (
                <Alert className="mt-6">
                  <svg
                    xmlns="http://www.w3.org/2000/svg"
                    width="16"
                    height="16"
                    viewBox="0 0 24 24"
                    fill="none"
                    stroke="currentColor"
                    strokeWidth="2"
                    strokeLinecap="round"
                    strokeLinejoin="round"
                  >
                    <circle cx="12" cy="12" r="10" />
                    <line x1="12" x2="12" y1="8" y2="12" />
                    <line x1="12" x2="12.01" y1="16" y2="16" />
                  </svg>
                  <AlertTitle>Configuración Requerida</AlertTitle>
                  <AlertDescription>
                    Debe configurar su firma digital antes de poder firmar documentos.
                  </AlertDescription>
                </Alert>
              )}
            </CardContent>
          </Card>
        </TabsContent>
      </Tabs>
    </div>
  )
}
