<?php
class Certificado {
    private $conn;
    private $table_name = "certificados";
    
    public $id;
    public $participante_id;
    public $curso_id;
    public $codigo;
    public $fecha_emision;
    public $estado;
    public $archivo_pdf;
    
    public function __construct($db) {
        $this->conn = $db;
    }
    
    public function read() {
        $query = "SELECT c.*, p.nombre as participante_nombre, p.apellido as participante_apellido, 
                         p.cedula as participante_cedula, cu.nombre as curso_nombre 
                  FROM " . $this->table_name . " c
                  LEFT JOIN participantes p ON c.participante_id = p.id
                  LEFT JOIN cursos cu ON c.curso_id = cu.id
                  ORDER BY c.fecha_emision DESC";
        
        $stmt = $this->conn->prepare($query);
        $stmt->execute();
        
        return $stmt;
    }
    
    public function readOne() {
        $query = "SELECT c.*, p.nombre as participante_nombre, p.apellido as participante_apellido, 
                         p.cedula as participante_cedula, cu.nombre as curso_nombre, 
                         cu.duracion_horas, cu.fecha_inicio, cu.fecha_fin 
                  FROM " . $this->table_name . " c
                  LEFT JOIN participantes p ON c.participante_id = p.id
                  LEFT JOIN cursos cu ON c.curso_id = cu.id
                  WHERE c.id = ? LIMIT 0,1";
        
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $this->id);
        $stmt->execute();
        
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if($row) {
            $this->participante_id = $row['participante_id'];
            $this->curso_id = $row['curso_id'];
            $this->codigo = $row['codigo'];
            $this->fecha_emision = $row['fecha_emision'];
            $this->estado = $row['estado'];
            $this->archivo_pdf = $row['archivo_pdf'];
            
            return $row;
        }
        
        return false;
    }
    
    public function create() {
        $query = "INSERT INTO " . $this->table_name . " 
                  SET participante_id=:participante_id, curso_id=:curso_id, 
                      codigo=:codigo, fecha_emision=:fecha_emision, 
                      estado=:estado, archivo_pdf=:archivo_pdf";
        
        $stmt = $this->conn->prepare($query);
        
        // Sanitizar datos
        $this->participante_id = htmlspecialchars(strip_tags($this->participante_id));
        $this->curso_id = htmlspecialchars(strip_tags($this->curso_id));
        $this->codigo = htmlspecialchars(strip_tags($this->codigo));
        $this->estado = htmlspecialchars(strip_tags($this->estado));
        $this->archivo_pdf = htmlspecialchars(strip_tags($this->archivo_pdf));
        
        $fecha_emision = date('Y-m-d H:i:s');
        
        // Vincular valores
        $stmt->bindParam(":participante_id", $this->participante_id);
        $stmt->bindParam(":curso_id", $this->curso_id);
        $stmt->bindParam(":codigo", $this->codigo);
        $stmt->bindParam(":fecha_emision", $fecha_emision);
        $stmt->bindParam(":estado", $this->estado);
        $stmt->bindParam(":archivo_pdf", $this->archivo_pdf);
        
        if($stmt->execute()) {
            $this->id = $this->conn->lastInsertId();
            return true;
        }
        
        return false;
    }
    
    public function update() {
        $query = "UPDATE " . $this->table_name . " 
                  SET participante_id=:participante_id, curso_id=:curso_id, 
                      codigo=:codigo, estado=:estado, archivo_pdf=:archivo_pdf 
                  WHERE id=:id";
        
        $stmt = $this->conn->prepare($query);
        
        // Sanitizar datos
        $this->id = htmlspecialchars(strip_tags($this->id));
        $this->participante_id = htmlspecialchars(strip_tags($this->participante_id));
        $this->curso_id = htmlspecialchars(strip_tags($this->curso_id));
        $this->codigo = htmlspecialchars(strip_tags($this->codigo));
        $this->estado = htmlspecialchars(strip_tags($this->estado));
        $this->archivo_pdf = htmlspecialchars(strip_tags($this->archivo_pdf));
        
        // Vincular valores
        $stmt->bindParam(":id", $this->id);
        $stmt->bindParam(":participante_id", $this->participante_id);
        $stmt->bindParam(":curso_id", $this->curso_id);
        $stmt->bindParam(":codigo", $this->codigo);
        $stmt->bindParam(":estado", $this->estado);
        $stmt->bindParam(":archivo_pdf", $this->archivo_pdf);
        
        if($stmt->execute()) {
            return true;
        }
        
        return false;
    }
    
    public function delete() {
        $query = "DELETE FROM " . $this->table_name . " WHERE id = ?";
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $this->id);
        
        if($stmt->execute()) {
            return true;
        }
        
        return false;
    }
    
    public function verificarPorCodigo($codigo) {
        $query = "SELECT c.*, p.nombre as participante_nombre, p.apellido as participante_apellido, 
                         p.cedula as participante_cedula, cu.nombre as curso_nombre, 
                         cu.duracion_horas, cu.fecha_inicio, cu.fecha_fin 
                  FROM " . $this->table_name . " c
                  LEFT JOIN participantes p ON c.participante_id = p.id
                  LEFT JOIN cursos cu ON c.curso_id = cu.id
                  WHERE c.codigo = ? LIMIT 0,1";
        
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $codigo);
        $stmt->execute();
        
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }
    
    public function generarCodigo() {
        return 'CERT-' . date('Y') . '-' . str_pad(rand(1, 9999), 4, '0', STR_PAD_LEFT);
    }
    
    public function getCertificadosPorParticipante($participante_id) {
        $query = "SELECT c.*, cu.nombre as curso_nombre, cu.duracion_horas 
                  FROM " . $this->table_name . " c
                  LEFT JOIN cursos cu ON c.curso_id = cu.id
                  WHERE c.participante_id = ?
                  ORDER BY c.fecha_emision DESC";
        
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $participante_id);
        $stmt->execute();
        
        return $stmt;
    }
    
    public function getCertificadosPorCurso($curso_id) {
        $query = "SELECT c.*, p.nombre as participante_nombre, p.apellido as participante_apellido, 
                         p.cedula as participante_cedula 
                  FROM " . $this->table_name . " c
                  LEFT JOIN participantes p ON c.participante_id = p.id
                  WHERE c.curso_id = ?
                  ORDER BY p.apellido, p.nombre";
        
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $curso_id);
        $stmt->execute();
        
        return $stmt;
    }
}
?>
