-- Base de datos para el sistema de certificados de bomberos
CREATE DATABASE IF NOT EXISTS bomberos_certificados;
USE bomberos_certificados;

-- Tabla de escuelas/dependencias
CREATE TABLE escuelas (
    id INT PRIMARY KEY AUTO_INCREMENT,
    nombre VARCHAR(255) NOT NULL,
    codigo VARCHAR(50) UNIQUE NOT NULL,
    direccion TEXT,
    telefono VARCHAR(20),
    email VARCHAR(255),
    estado ENUM('activo', 'inactivo') DEFAULT 'activo',
    fecha_creacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP
);

-- Tabla de usuarios
CREATE TABLE usuarios (
    id INT PRIMARY KEY AUTO_INCREMENT,
    email VARCHAR(255) UNIQUE NOT NULL,
    password_hash VARCHAR(255) NOT NULL,
    nombre VARCHAR(255) NOT NULL,
    rol ENUM('admin', 'director_nacional', 'educacion_dnbc', 'director_escuela', 'coordinador', 'escuela') NOT NULL,
    escuela_id INT,
    estado ENUM('activo', 'inactivo') DEFAULT 'activo',
    ultimo_acceso TIMESTAMP NULL,
    fecha_creacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (escuela_id) REFERENCES escuelas(id)
);

-- Tabla de participantes
CREATE TABLE participantes (
    id INT PRIMARY KEY AUTO_INCREMENT,
    nombres VARCHAR(255) NOT NULL,
    apellidos VARCHAR(255) NOT NULL,
    cedula VARCHAR(20) UNIQUE NOT NULL,
    correo VARCHAR(255) NOT NULL,
    celular VARCHAR(20),
    genero ENUM('Masculino', 'Femenino') NOT NULL,
    institucion VARCHAR(255) NOT NULL,
    fotografia VARCHAR(255),
    estado ENUM('activo', 'inactivo') DEFAULT 'activo',
    fecha_creacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP
);

-- Tabla de cursos
CREATE TABLE cursos (
    id INT PRIMARY KEY AUTO_INCREMENT,
    nombre VARCHAR(255) NOT NULL,
    codigo VARCHAR(50) UNIQUE NOT NULL,
    descripcion TEXT,
    coordinador_id INT NOT NULL,
    numero_registro VARCHAR(100) NOT NULL,
    fecha_inicio DATE NOT NULL,
    fecha_fin DATE NOT NULL,
    duracion_horas INT NOT NULL,
    modalidad ENUM('presencial', 'virtual', 'mixta') NOT NULL,
    contenido_tematico TEXT NOT NULL,
    objetivos TEXT,
    metodologia TEXT,
    evaluacion TEXT,
    requisitos TEXT,
    cupos INT DEFAULT 30,
    estado ENUM('programado', 'en_curso', 'finalizado', 'cancelado') DEFAULT 'programado',
    escuela_id INT NOT NULL,
    fecha_creacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (coordinador_id) REFERENCES usuarios(id),
    FOREIGN KEY (escuela_id) REFERENCES escuelas(id)
);

-- Tabla de matrículas
CREATE TABLE matriculas (
    id INT PRIMARY KEY AUTO_INCREMENT,
    participante_id INT NOT NULL,
    curso_id INT NOT NULL,
    fecha_matricula TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    estado ENUM('activo', 'cancelado') DEFAULT 'activo',
    FOREIGN KEY (participante_id) REFERENCES participantes(id),
    FOREIGN KEY (curso_id) REFERENCES cursos(id),
    UNIQUE KEY unique_matricula (participante_id, curso_id)
);

-- Tabla de calificaciones
CREATE TABLE calificaciones (
    id INT PRIMARY KEY AUTO_INCREMENT,
    matricula_id INT NOT NULL,
    calificacion_teorica DECIMAL(5,2) DEFAULT 0,
    calificacion_practica DECIMAL(5,2) DEFAULT 0,
    calificacion_final DECIMAL(5,2) GENERATED ALWAYS AS (calificacion_teorica * 0.4 + calificacion_practica * 0.6) STORED,
    estado ENUM('aprobado', 'no_aprobado') GENERATED ALWAYS AS (
        CASE WHEN (calificacion_teorica * 0.4 + calificacion_practica * 0.6) >= 70 THEN 'aprobado' ELSE 'no_aprobado' END
    ) STORED,
    observaciones TEXT,
    fecha_calificacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (matricula_id) REFERENCES matriculas(id)
);

-- Tabla de certificados
CREATE TABLE certificados (
    id INT PRIMARY KEY AUTO_INCREMENT,
    matricula_id INT NOT NULL,
    codigo_verificacion VARCHAR(100) UNIQUE NOT NULL,
    fecha_emision TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    estado ENUM('pendiente_coordinador', 'pendiente_director_escuela', 'pendiente_educacion_dnbc', 'pendiente_director_nacional', 'completado') DEFAULT 'pendiente_coordinador',
    archivo_pdf VARCHAR(255),
    hash_documento VARCHAR(255),
    FOREIGN KEY (matricula_id) REFERENCES matriculas(id)
);

-- Tabla de firmas digitales
CREATE TABLE firmas_digitales (
    id INT PRIMARY KEY AUTO_INCREMENT,
    usuario_id INT NOT NULL,
    certificado_id INT NOT NULL,
    tipo_firma ENUM('coordinador', 'director_escuela', 'educacion_dnbc', 'director_nacional') NOT NULL,
    firma_digital TEXT,
    hash_firma VARCHAR(255),
    fecha_firma TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    ip_address VARCHAR(45),
    FOREIGN KEY (usuario_id) REFERENCES usuarios(id),
    FOREIGN KEY (certificado_id) REFERENCES certificados(id)
);

-- Tabla de configuración de firmas por usuario
CREATE TABLE configuracion_firmas (
    id INT PRIMARY KEY AUTO_INCREMENT,
    usuario_id INT NOT NULL,
    tipo_firma ENUM('imagen', 'criptografica') NOT NULL,
    imagen_firma VARCHAR(255),
    certificado_digital LONGBLOB,
    clave_privada_hash VARCHAR(255),
    configurada BOOLEAN DEFAULT FALSE,
    fecha_configuracion TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (usuario_id) REFERENCES usuarios(id)
);

-- Tabla de logs del sistema
CREATE TABLE logs_sistema (
    id INT PRIMARY KEY AUTO_INCREMENT,
    usuario_id INT,
    accion VARCHAR(255) NOT NULL,
    tabla_afectada VARCHAR(100),
    registro_id INT,
    datos_anteriores JSON,
    datos_nuevos JSON,
    ip_address VARCHAR(45),
    user_agent TEXT,
    fecha_accion TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (usuario_id) REFERENCES usuarios(id)
);

-- Insertar datos iniciales
INSERT INTO escuelas (nombre, codigo, direccion, telefono, email) VALUES
('Dirección Nacional de Bomberos Colombia', 'DNBC', 'Bogotá D.C.', '601-1234567', 'info@bomberos.gov.co'),
('Escuela Nacional de Bomberos', 'ENB', 'Bogotá D.C.', '601-1234568', 'escuela.nacional@bomberos.gov.co'),
('Escuela Regional Bogotá', 'ERB', 'Bogotá D.C.', '601-1234569', 'bogota@bomberos.gov.co'),
('Escuela Regional Medellín', 'ERM', 'Medellín, Antioquia', '604-1234567', 'medellin@bomberos.gov.co'),
('Escuela Regional Cali', 'ERC', 'Cali, Valle del Cauca', '602-1234567', 'cali@bomberos.gov.co');

-- Insertar usuarios iniciales
INSERT INTO usuarios (email, password_hash, nombre, rol, escuela_id) VALUES
('admin@bomberos.gov.co', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'Administrador General', 'admin', 1),
('director.nacional@bomberos.gov.co', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'Director Nacional', 'director_nacional', 1),
('educacion@bomberos.gov.co', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'Jefe de Educación DNBC', 'educacion_dnbc', 1),
('carlos.martinez@bomberos.gov.co', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'Carlos Martínez', 'coordinador', 2),
('laura.gomez@bomberos.gov.co', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'Laura Gómez', 'director_escuela', 3);

-- Nota: La contraseña para todos los usuarios es "password123"
