<?php
class Certificado {
    private $conn;
    private $table_name = "certificados";

    public $id;
    public $matricula_id;
    public $codigo_verificacion;
    public $fecha_emision;
    public $estado;
    public $archivo_pdf;
    public $hash_documento;
    
    // Campos relacionados
    public $participante_nombre;
    public $participante_apellidos;
    public $curso_nombre;
    public $calificacion_final;

    public function __construct($db) {
        $this->conn = $db;
    }

    public function read() {
        $query = "SELECT c.*, 
                         p.nombres as participante_nombre, 
                         p.apellidos as participante_apellidos,
                         cur.nombre as curso_nombre,
                         cal.calificacion_final
                  FROM " . $this->table_name . " c
                  INNER JOIN matriculas m ON c.matricula_id = m.id
                  INNER JOIN participantes p ON m.participante_id = p.id
                  INNER JOIN cursos cur ON m.curso_id = cur.id
                  LEFT JOIN calificaciones cal ON m.id = cal.matricula_id
                  ORDER BY c.fecha_emision DESC";

        $stmt = $this->conn->prepare($query);
        $stmt->execute();

        return $stmt;
    }

    public function create() {
        $query = "INSERT INTO " . $this->table_name . " 
                  (matricula_id, codigo_verificacion) 
                  VALUES (?, ?)";

        $stmt = $this->conn->prepare($query);

        $stmt->bindParam(1, $this->matricula_id);
        $stmt->bindParam(2, $this->codigo_verificacion);

        if ($stmt->execute()) {
            $this->id = $this->conn->lastInsertId();
            return true;
        }

        return false;
    }

    public function update() {
        $query = "UPDATE " . $this->table_name . " 
                  SET archivo_pdf = ?, hash_documento = ? 
                  WHERE id = ?";

        $stmt = $this->conn->prepare($query);

        $stmt->bindParam(1, $this->archivo_pdf);
        $stmt->bindParam(2, $this->hash_documento);
        $stmt->bindParam(3, $this->id);

        return $stmt->execute();
    }

    public function verificar() {
        $query = "SELECT c.*, 
                         p.nombres as participante_nombre, 
                         p.apellidos as participante_apellidos,
                         cur.nombre as curso_nombre,
                         cal.calificacion_final
                  FROM " . $this->table_name . " c
                  INNER JOIN matriculas m ON c.matricula_id = m.id
                  INNER JOIN participantes p ON m.participante_id = p.id
                  INNER JOIN cursos cur ON m.curso_id = cur.id
                  LEFT JOIN calificaciones cal ON m.id = cal.matricula_id
                  WHERE c.codigo_verificacion = ? AND c.estado = 'completado'";

        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(1, $this->codigo_verificacion);
        $stmt->execute();

        $row = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($row) {
            $this->id = $row['id'];
            $this->participante_nombre = $row['participante_nombre'];
            $this->participante_apellidos = $row['participante_apellidos'];
            $this->curso_nombre = $row['curso_nombre'];
            $this->fecha_emision = $row['fecha_emision'];
            $this->calificacion_final = $row['calificacion_final'];
            return true;
        }

        return false;
    }

    public function firmar($usuario_id, $tipo_firma, $firma_digital = null) {
        $this->conn->beginTransaction();
        
        try {
            // Insertar firma
            $query_firma = "INSERT INTO firmas_digitales 
                           (usuario_id, certificado_id, tipo_firma, firma_digital, hash_firma, ip_address) 
                           VALUES (?, ?, ?, ?, ?, ?)";
            
            $stmt_firma = $this->conn->prepare($query_firma);
            $hash_firma = $firma_digital ? hash('sha256', $firma_digital) : null;
            $ip_address = $_SERVER['REMOTE_ADDR'] ?? null;
            
            $stmt_firma->execute([
                $usuario_id,
                $this->id,
                $tipo_firma,
                $firma_digital,
                $hash_firma,
                $ip_address
            ]);
            
            // Actualizar estado del certificado
            $nuevo_estado = $this->getNextEstado($tipo_firma);
            
            $query_estado = "UPDATE " . $this->table_name . " 
                            SET estado = ? 
                            WHERE id = ?";
            
            $stmt_estado = $this->conn->prepare($query_estado);
            $stmt_estado->execute([$nuevo_estado, $this->id]);
            
            $this->conn->commit();
            return true;
        } catch (Exception $e) {
            $this->conn->rollback();
            return false;
        }
    }

    public function getPendientesFirma() {
        $query = "SELECT c.*, 
                         p.nombres as participante_nombre, 
                         p.apellidos as participante_apellidos,
                         cur.nombre as curso_nombre
                  FROM " . $this->table_name . " c
                  INNER JOIN matriculas m ON c.matricula_id = m.id
                  INNER JOIN participantes p ON m.participante_id = p.id
                  INNER JOIN cursos cur ON m.curso_id = cur.id
                  WHERE c.estado != 'completado'
                  ORDER BY c.fecha_emision ASC";

        $stmt = $this->conn->prepare($query);
        $stmt->execute();

        return $stmt;
    }

    public function generarCodigoVerificacion() {
        return 'CERT-' . date('Y') . '-' . strtoupper(substr(md5(uniqid(rand(), true)), 0, 8));
    }

    public function getMatriculaId($participante_id, $curso_id) {
        $query = "SELECT id FROM matriculas 
                  WHERE participante_id = ? AND curso_id = ? AND estado = 'activo'";
        
        $stmt = $this->conn->prepare($query);
        $stmt->execute([$participante_id, $curso_id]);
        
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        return $row ? $row['id'] : null;
    }

    private function getNextEstado($tipo_firma) {
        switch ($tipo_firma) {
            case 'coordinador':
                return 'pendiente_director_escuela';
            case 'director_escuela':
                return 'pendiente_educacion_dnbc';
            case 'educacion_dnbc':
                return 'pendiente_director_nacional';
            case 'director_nacional':
                return 'completado';
            default:
                return $this->estado;
        }
    }
}
?>
