<?php
require_once '../vendor/autoload.php'; // Para TCPDF o similar

class PDFGenerator {
    private $conn;
    
    public function __construct() {
        $database = new Database();
        $this->conn = $database->getConnection();
    }
    
    public function generarCertificado($certificado_id, $opciones = null) {
        // Obtener datos del certificado
        $datos = $this->obtenerDatosCertificado($certificado_id);
        
        if (!$datos) {
            throw new Exception("No se encontraron datos para el certificado");
        }
        
        // Crear PDF
        $pdf = new TCPDF(PDF_PAGE_ORIENTATION, PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);
        
        // Configurar PDF
        $pdf->SetCreator('DNBC - Sistema de Certificados');
        $pdf->SetAuthor('Dirección Nacional de Bomberos Colombia');
        $pdf->SetTitle('Certificado de Participación');
        $pdf->SetSubject('Certificado de Curso');
        
        // Configurar márgenes
        $pdf->SetMargins(20, 20, 20);
        $pdf->SetAutoPageBreak(TRUE, 20);
        
        // Agregar página
        $pdf->AddPage();
        
        // Generar contenido
        $this->generarContenidoCertificado($pdf, $datos, $opciones);
        
        // Guardar archivo
        $filename = 'certificado_' . $datos['codigo_verificacion'] . '.pdf';
        $filepath = '../storage/certificados/' . $filename;
        
        // Crear directorio si no existe
        if (!file_exists('../storage/certificados/')) {
            mkdir('../storage/certificados/', 0777, true);
        }
        
        $pdf->Output($filepath, 'F');
        
        return $filename;
    }
    
    private function obtenerDatosCertificado($certificado_id) {
        $query = "SELECT c.*, 
                         p.nombres, p.apellidos, p.cedula,
                         cur.nombre as curso_nombre, cur.fecha_inicio, cur.fecha_fin, cur.duracion_horas,
                         cal.calificacion_final,
                         e.nombre as escuela_nombre
                  FROM certificados c
                  INNER JOIN matriculas m ON c.matricula_id = m.id
                  INNER JOIN participantes p ON m.participante_id = p.id
                  INNER JOIN cursos cur ON m.curso_id = cur.id
                  INNER JOIN escuelas e ON cur.escuela_id = e.id
                  LEFT JOIN calificaciones cal ON m.id = cal.matricula_id
                  WHERE c.id = ?";
        
        $stmt = $this->conn->prepare($query);
        $stmt->execute([$certificado_id]);
        
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }
    
    private function generarContenidoCertificado($pdf, $datos, $opciones) {
        // Logo y encabezado
        $pdf->SetFont('helvetica', 'B', 16);
        $pdf->SetTextColor(139, 0, 0); // Color rojo bomberos
        $pdf->Cell(0, 15, 'DIRECCIÓN NACIONAL DE BOMBEROS COLOMBIA', 0, 1, 'C');
        
        $pdf->SetFont('helvetica', '', 12);
        $pdf->SetTextColor(0, 0, 0);
        $pdf->Cell(0, 10, $datos['escuela_nombre'], 0, 1, 'C');
        
        $pdf->Ln(10);
        
        // Título del certificado
        $pdf->SetFont('helvetica', 'B', 20);
        $pdf->Cell(0, 15, 'CERTIFICADO DE PARTICIPACIÓN', 0, 1, 'C');
        
        $pdf->Ln(15);
        
        // Contenido principal
        $pdf->SetFont('helvetica', '', 14);
        $pdf->Cell(0, 10, 'Se certifica que', 0, 1, 'C');
        
        $pdf->Ln(5);
        
        $pdf->SetFont('helvetica', 'B', 18);
        $nombre_completo = $datos['nombres'] . ' ' . $datos['apellidos'];
        $pdf->Cell(0, 15, $nombre_completo, 0, 1, 'C');
        
        $pdf->Ln(5);
        
        $pdf->SetFont('helvetica', '', 14);
        $pdf->Cell(0, 10, 'identificado(a) con cédula de ciudadanía No. ' . $datos['cedula'], 0, 1, 'C');
        
        $pdf->Ln(5);
        
        $pdf->Cell(0, 10, 'participó exitosamente en el curso', 0, 1, 'C');
        
        $pdf->Ln(5);
        
        $pdf->SetFont('helvetica', 'B', 16);
        $pdf->MultiCell(0, 10, $datos['curso_nombre'], 0, 'C');
        
        $pdf->Ln(10);
        
        // Información adicional según opciones
        $pdf->SetFont('helvetica', '', 12);
        
        if ($opciones && $opciones->incluirFechas) {
            $pdf->Cell(0, 8, 'Realizado del ' . date('d/m/Y', strtotime($datos['fecha_inicio'])) . 
                      ' al ' . date('d/m/Y', strtotime($datos['fecha_fin'])), 0, 1, 'C');
            $pdf->Cell(0, 8, 'Con una duración de ' . $datos['duracion_horas'] . ' horas académicas', 0, 1, 'C');
        }
        
        if ($opciones && $opciones->incluirCalificacion && $datos['calificacion_final']) {
            $pdf->Ln(5);
            $pdf->Cell(0, 8, 'Calificación obtenida: ' . number_format($datos['calificacion_final'], 1) . '/100', 0, 1, 'C');
        }
        
        $pdf->Ln(15);
        
        // Código de verificación
        $pdf->SetFont('helvetica', '', 10);
        $pdf->Cell(0, 8, 'Código de verificación: ' . $datos['codigo_verificacion'], 0, 1, 'C');
        
        // QR Code si está habilitado
        if ($opciones && $opciones->incluirCodigoQR) {
            $this->generarQRCode($pdf, $datos['codigo_verificacion']);
        }
        
        $pdf->Ln(20);
        
        // Firmas
        if ($opciones && $opciones->incluirFirmas) {
            $this->generarSeccionFirmas($pdf, $datos);
        }
        
        // Fecha de emisión
        $pdf->Ln(10);
        $pdf->SetFont('helvetica', '', 10);
        $pdf->Cell(0, 8, 'Bogotá D.C., ' . date('d \d\e F \d\e Y', strtotime($datos['fecha_emision'])), 0, 1, 'C');
    }
    
    private function generarQRCode($pdf, $codigo) {
        // Generar QR code con la URL de verificación
        $url_verificacion = 'https://certificados.bomberos.gov.co/verificar/' . $codigo;
        
        // Usar biblioteca QR code (ejemplo con qrcode.js o similar)
        $qr_size = 30;
        $x = ($pdf->getPageWidth() - $qr_size) / 2;
        $y = $pdf->GetY();
        
        // Aquí iría la implementación del QR code
        // $pdf->write2DBarcode($url_verificacion, 'QRCODE,L', $x, $y, $qr_size, $qr_size);
        
        $pdf->Ln($qr_size + 5);
    }
    
    private function generarSeccionFirmas($pdf, $datos) {
        $pdf->SetFont('helvetica', '', 10);
        
        // Obtener firmas del certificado
        $firmas = $this->obtenerFirmas($datos['id']);
        
        $y_inicial = $pdf->GetY();
        $ancho_firma = 80;
        $x_izq = 30;
        $x_der = $pdf->getPageWidth() - $ancho_firma - 30;
        
        // Firma del coordinador
        $pdf->SetXY($x_izq, $y_inicial);
        $pdf->Cell($ancho_firma, 5, '_________________________', 0, 1, 'C');
        $pdf->SetX($x_izq);
        $pdf->Cell($ancho_firma, 5, 'Coordinador del Curso', 0, 1, 'C');
        
        // Firma del director nacional
        $pdf->SetXY($x_der, $y_inicial);
        $pdf->Cell($ancho_firma, 5, '_________________________', 0, 1, 'C');
        $pdf->SetX($x_der);
        $pdf->Cell($ancho_firma, 5, 'Director Nacional', 0, 1, 'C');
        
        if (isset($firmas['coordinador'])) {
            $pdf->SetXY($x_izq, $y_inicial + 10);
            $pdf->SetFont('helvetica', '', 8);
            $pdf->Cell($ancho_firma, 3, 'Firmado digitalmente el:', 0, 1, 'C');
            $pdf->SetX($x_izq);
            $pdf->Cell($ancho_firma, 3, date('d/m/Y H:i', strtotime($firmas['coordinador']['fecha_firma'])), 0, 1, 'C');
        }
        
        if (isset($firmas['director_nacional'])) {
            $pdf->SetXY($x_der, $y_inicial + 10);
            $pdf->SetFont('helvetica', '', 8);
            $pdf->Cell($ancho_firma, 3, 'Firmado digitalmente el:', 0, 1, 'C');
            $pdf->SetX($x_der);
            $pdf->Cell($ancho_firma, 3, date('d/m/Y H:i', strtotime($firmas['director_nacional']['fecha_firma'])), 0, 1, 'C');
        }
    }
    
    private function obtenerFirmas($certificado_id) {
        $query = "SELECT f.*, u.nombre 
                  FROM firmas_digitales f
                  INNER JOIN usuarios u ON f.usuario_id = u.id
                  WHERE f.certificado_id = ?";
        
        $stmt = $this->conn->prepare($query);
        $stmt->execute([$certificado_id]);
        
        $firmas = [];
        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
            $firmas[$row['tipo_firma']] = $row;
        }
        
        return $firmas;
    }
}
?>
