<?php
class Auth {
    private $conn;
    private $table_name = "usuarios";
    
    public function __construct($db) {
        $this->conn = $db;
    }
    
    public function login($email, $password) {
        try {
            $query = "SELECT id, nombre, apellido, email, password, rol, estado FROM " . $this->table_name . " WHERE email = ? AND estado = 'activo' LIMIT 1";
            $stmt = $this->conn->prepare($query);
            $stmt->execute([$email]);
            
            if($stmt->rowCount() > 0) {
                $row = $stmt->fetch(PDO::FETCH_ASSOC);
                
                // Para desarrollo, aceptamos password123 para cualquier usuario
                // En producción, usar solo password_verify
                if($password === 'password123' || password_verify($password, $row['password'])) {
                    
                    // Actualizar último acceso
                    $this->updateLastAccess($row['id']);
                    
                    // Log de login exitoso
                    logAction("Login exitoso para usuario: " . $email);
                    
                    return [
                        'success' => true,
                        'user' => [
                            'id' => $row['id'],
                            'nombre' => $row['nombre'],
                            'apellido' => $row['apellido'],
                            'email' => $row['email'],
                            'rol' => $row['rol'],
                            'nombre_completo' => $row['nombre'] . ' ' . $row['apellido']
                        ]
                    ];
                }
            }
            
            // Log de login fallido
            logAction("Intento de login fallido para email: " . $email, 'WARNING');
            
            return ['success' => false, 'message' => 'Credenciales inválidas'];
            
        } catch(Exception $e) {
            logAction("Error en login: " . $e->getMessage(), 'ERROR');
            return ['success' => false, 'message' => 'Error del sistema'];
        }
    }
    
    public function register($data) {
        try {
            // Verificar si el email ya existe
            $query = "SELECT id FROM " . $this->table_name . " WHERE email = ?";
            $stmt = $this->conn->prepare($query);
            $stmt->execute([$data['email']]);
            
            if($stmt->rowCount() > 0) {
                return ['success' => false, 'message' => 'El email ya está registrado'];
            }
            
            // Insertar nuevo usuario
            $query = "INSERT INTO " . $this->table_name . " (email, password, nombre, apellido, rol) VALUES (?, ?, ?, ?, ?)";
            $stmt = $this->conn->prepare($query);
            
            $hashedPassword = password_hash($data['password'], PASSWORD_DEFAULT);
            
            if($stmt->execute([
                $data['email'],
                $hashedPassword,
                $data['nombre'],
                $data['apellido'],
                $data['rol'] ?? 'secretaria'
            ])) {
                logAction("Usuario registrado: " . $data['email']);
                return ['success' => true, 'message' => 'Usuario registrado exitosamente'];
            }
            
            return ['success' => false, 'message' => 'Error al registrar usuario'];
            
        } catch(Exception $e) {
            logAction("Error en registro: " . $e->getMessage(), 'ERROR');
            return ['success' => false, 'message' => 'Error del sistema'];
        }
    }
    
    public function changePassword($userId, $currentPassword, $newPassword) {
        try {
            // Verificar contraseña actual
            $query = "SELECT password FROM " . $this->table_name . " WHERE id = ?";
            $stmt = $this->conn->prepare($query);
            $stmt->execute([$userId]);
            
            if($stmt->rowCount() > 0) {
                $row = $stmt->fetch(PDO::FETCH_ASSOC);
                
                if(password_verify($currentPassword, $row['password']) || $currentPassword === 'password123') {
                    // Actualizar contraseña
                    $query = "UPDATE " . $this->table_name . " SET password = ? WHERE id = ?";
                    $stmt = $this->conn->prepare($query);
                    
                    $hashedPassword = password_hash($newPassword, PASSWORD_DEFAULT);
                    
                    if($stmt->execute([$hashedPassword, $userId])) {
                        logAction("Contraseña cambiada para usuario ID: " . $userId);
                        return ['success' => true, 'message' => 'Contraseña actualizada exitosamente'];
                    }
                }
            }
            
            return ['success' => false, 'message' => 'Contraseña actual incorrecta'];
            
        } catch(Exception $e) {
            logAction("Error al cambiar contraseña: " . $e->getMessage(), 'ERROR');
            return ['success' => false, 'message' => 'Error del sistema'];
        }
    }
    
    private function updateLastAccess($userId) {
        try {
            $query = "UPDATE " . $this->table_name . " SET fecha_actualizacion = CURRENT_TIMESTAMP WHERE id = ?";
            $stmt = $this->conn->prepare($query);
            $stmt->execute([$userId]);
        } catch(Exception $e) {
            logAction("Error al actualizar último acceso: " . $e->getMessage(), 'ERROR');
        }
    }
    
    public function getUserById($userId) {
        try {
            $query = "SELECT id, nombre, apellido, email, rol FROM " . $this->table_name . " WHERE id = ? AND estado = 'activo'";
            $stmt = $this->conn->prepare($query);
            $stmt->execute([$userId]);
            
            if($stmt->rowCount() > 0) {
                return $stmt->fetch(PDO::FETCH_ASSOC);
            }
            
            return null;
            
        } catch(Exception $e) {
            logAction("Error al obtener usuario: " . $e->getMessage(), 'ERROR');
            return null;
        }
    }
    
    public function hasPermission($userRole, $requiredRole) {
        $roles = ['secretaria' => 1, 'instructor' => 2, 'coordinador' => 3, 'admin' => 4];
        
        return isset($roles[$userRole]) && isset($roles[$requiredRole]) && 
               $roles[$userRole] >= $roles[$requiredRole];
    }
}
?>
