<?php
class Curso {
    private $conn;
    private $table_name = "cursos";
    
    public function __construct($db) {
        $this->conn = $db;
    }
    
    public function getAll($limit = null, $offset = 0, $search = '') {
        try {
            $whereClause = '';
            $params = [];
            
            if (!empty($search)) {
                $whereClause = "WHERE codigo LIKE ? OR nombre LIKE ? OR instructor LIKE ? OR lugar LIKE ?";
                $searchTerm = "%{$search}%";
                $params = [$searchTerm, $searchTerm, $searchTerm, $searchTerm];
            }
            
            $limitClause = '';
            if ($limit) {
                $limitClause = "LIMIT ? OFFSET ?";
                $params[] = $limit;
                $params[] = $offset;
            }
            
            $query = "SELECT * FROM " . $this->table_name . " $whereClause ORDER BY fecha_inicio DESC $limitClause";
            $stmt = $this->conn->prepare($query);
            $stmt->execute($params);
            
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
            
        } catch(Exception $e) {
            logAction("Error al obtener cursos: " . $e->getMessage(), 'ERROR');
            return [];
        }
    }
    
    public function getById($id) {
        try {
            $query = "SELECT * FROM " . $this->table_name . " WHERE id = ?";
            $stmt = $this->conn->prepare($query);
            $stmt->execute([$id]);
            
            return $stmt->fetch(PDO::FETCH_ASSOC);
            
        } catch(Exception $e) {
            logAction("Error al obtener curso: " . $e->getMessage(), 'ERROR');
            return null;
        }
    }
    
    public function create($data) {
        try {
            // Verificar si el código ya existe
            $query = "SELECT id FROM " . $this->table_name . " WHERE codigo = ?";
            $stmt = $this->conn->prepare($query);
            $stmt->execute([$data['codigo']]);
            
            if ($stmt->rowCount() > 0) {
                return ['success' => false, 'message' => 'Ya existe un curso con este código'];
            }
            
            $query = "INSERT INTO " . $this->table_name . " 
                      (codigo, nombre, descripcion, tipo, modalidad, duracion_horas, fecha_inicio, 
                       fecha_fin, instructor, lugar, cupo_maximo, costo, contenido_tematico, 
                       objetivos, metodologia, evaluacion, requisitos, estado) 
                      VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
            
            $stmt = $this->conn->prepare($query);
            
            if ($stmt->execute([
                $data['codigo'],
                $data['nombre'],
                $data['descripcion'] ?? null,
                $data['tipo'] ?? 'capacitacion',
                $data['modalidad'] ?? 'presencial',
                $data['duracion_horas'],
                $data['fecha_inicio'],
                $data['fecha_fin'] ?? null,
                $data['instructor'] ?? null,
                $data['lugar'] ?? null,
                $data['cupo_maximo'] ?? 30,
                $data['costo'] ?? 0.00,
                $data['contenido_tematico'] ?? null,
                $data['objetivos'] ?? null,
                $data['metodologia'] ?? null,
                $data['evaluacion'] ?? null,
                $data['requisitos'] ?? null,
                $data['estado'] ?? 'programado'
            ])) {
                $id = $this->conn->lastInsertId();
                logAction("Curso creado: " . $data['nombre'] . " (ID: $id)");
                return ['success' => true, 'message' => 'Curso creado exitosamente', 'id' => $id];
            }
            
            return ['success' => false, 'message' => 'Error al crear curso'];
            
        } catch(Exception $e) {
            logAction("Error al crear curso: " . $e->getMessage(), 'ERROR');
            return ['success' => false, 'message' => 'Error del sistema: ' . $e->getMessage()];
        }
    }
    
    public function update($id, $data) {
        try {
            // Verificar si el código ya existe en otro registro
            $query = "SELECT id FROM " . $this->table_name . " WHERE codigo = ? AND id != ?";
            $stmt = $this->conn->prepare($query);
            $stmt->execute([$data['codigo'], $id]);
            
            if ($stmt->rowCount() > 0) {
                return ['success' => false, 'message' => 'Ya existe otro curso con este código'];
            }
            
            $query = "UPDATE " . $this->table_name . " 
                      SET codigo=?, nombre=?, descripcion=?, tipo=?, modalidad=?, duracion_horas=?, 
                          fecha_inicio=?, fecha_fin=?, instructor=?, lugar=?, cupo_maximo=?, costo=?, 
                          contenido_tematico=?, objetivos=?, metodologia=?, evaluacion=?, requisitos=?, estado=?
                      WHERE id=?";
            
            $stmt = $this->conn->prepare($query);
            
            if ($stmt->execute([
                $data['codigo'],
                $data['nombre'],
                $data['descripcion'] ?? null,
                $data['tipo'] ?? 'capacitacion',
                $data['modalidad'] ?? 'presencial',
                $data['duracion_horas'],
                $data['fecha_inicio'],
                $data['fecha_fin'] ?? null,
                $data['instructor'] ?? null,
                $data['lugar'] ?? null,
                $data['cupo_maximo'] ?? 30,
                $data['costo'] ?? 0.00,
                $data['contenido_tematico'] ?? null,
                $data['objetivos'] ?? null,
                $data['metodologia'] ?? null,
                $data['evaluacion'] ?? null,
                $data['requisitos'] ?? null,
                $data['estado'] ?? 'programado',
                $id
            ])) {
                logAction("Curso actualizado: ID $id");
                return ['success' => true, 'message' => 'Curso actualizado exitosamente'];
            }
            
            return ['success' => false, 'message' => 'Error al actualizar curso'];
            
        } catch(Exception $e) {
            logAction("Error al actualizar curso: " . $e->getMessage(), 'ERROR');
            return ['success' => false, 'message' => 'Error del sistema: ' . $e->getMessage()];
        }
    }
    
    public function delete($id) {
        try {
            // Verificar si tiene matrículas
            $query = "SELECT COUNT(*) as count FROM matriculas WHERE curso_id = ?";
            $stmt = $this->conn->prepare($query);
            $stmt->execute([$id]);
            $result = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if ($result['count'] > 0) {
                return ['success' => false, 'message' => 'No se puede eliminar: el curso tiene participantes matriculados'];
            }
            
            $query = "DELETE FROM " . $this->table_name . " WHERE id = ?";
            $stmt = $this->conn->prepare($query);
            
            if ($stmt->execute([$id])) {
                logAction("Curso eliminado: ID $id");
                return ['success' => true, 'message' => 'Curso eliminado exitosamente'];
            }
            
            return ['success' => false, 'message' => 'Error al eliminar curso'];
            
        } catch(Exception $e) {
            logAction("Error al eliminar curso: " . $e->getMessage(), 'ERROR');
            return ['success' => false, 'message' => 'Error del sistema: ' . $e->getMessage()];
        }
    }
    
    public function getCount($search = '') {
        try {
            $whereClause = '';
            $params = [];
            
            if (!empty($search)) {
                $whereClause = "WHERE codigo LIKE ? OR nombre LIKE ? OR instructor LIKE ? OR lugar LIKE ?";
                $searchTerm = "%{$search}%";
                $params = [$searchTerm, $searchTerm, $searchTerm, $searchTerm];
            }
            
            $query = "SELECT COUNT(*) as total FROM " . $this->table_name . " $whereClause";
            $stmt = $this->conn->prepare($query);
            $stmt->execute($params);
            
            $result = $stmt->fetch(PDO::FETCH_ASSOC);
            return $result['total'];
            
        } catch(Exception $e) {
            logAction("Error al contar cursos: " . $e->getMessage(), 'ERROR');
            return 0;
        }
    }
    
    public function getMatriculas($cursoId) {
        try {
            $query = "SELECT m.*, p.cedula, p.nombre, p.apellido, p.email, p.telefono, p.institucion,
                             cal.nota_final, cal.estado as estado_calificacion
                      FROM matriculas m
                      INNER JOIN participantes p ON m.participante_id = p.id
                      LEFT JOIN calificaciones cal ON m.id = cal.matricula_id
                      WHERE m.curso_id = ?
                      ORDER BY p.apellido, p.nombre";
            
            $stmt = $this->conn->prepare($query);
            $stmt->execute([$cursoId]);
            
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
            
        } catch(Exception $e) {
            logAction("Error al obtener matrículas del curso: " . $e->getMessage(), 'ERROR');
            return [];
        }
    }
    
    public function generateCodigo() {
        $year = date('Y');
        $prefix = 'CURSO-' . $year . '-';
        
        try {
            $query = "SELECT codigo FROM " . $this->table_name . " WHERE codigo LIKE ? ORDER BY codigo DESC LIMIT 1";
            $stmt = $this->conn->prepare($query);
            $stmt->execute([$prefix . '%']);
            
            $lastCode = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if ($lastCode) {
                $lastNumber = intval(substr($lastCode['codigo'], -3));
                $newNumber = $lastNumber + 1;
            } else {
                $newNumber = 1;
            }
            
            return $prefix . str_pad($newNumber, 3, '0', STR_PAD_LEFT);
            
        } catch(Exception $e) {
            logAction("Error al generar código de curso: " . $e->getMessage(), 'ERROR');
            return $prefix . '001';
        }
    }
}
?>
