<?php
class Participante {
    private $conn;
    private $table_name = "participantes";
    
    public function __construct($db) {
        $this->conn = $db;
    }
    
    public function getAll($limit = null, $offset = 0, $search = '') {
        try {
            $whereClause = '';
            $params = [];
            
            if (!empty($search)) {
                $whereClause = "WHERE cedula LIKE ? OR nombre LIKE ? OR apellido LIKE ? OR email LIKE ? OR institucion LIKE ?";
                $searchTerm = "%{$search}%";
                $params = [$searchTerm, $searchTerm, $searchTerm, $searchTerm, $searchTerm];
            }
            
            $limitClause = '';
            if ($limit) {
                $limitClause = "LIMIT ? OFFSET ?";
                $params[] = $limit;
                $params[] = $offset;
            }
            
            $query = "SELECT * FROM " . $this->table_name . " $whereClause ORDER BY apellido, nombre $limitClause";
            $stmt = $this->conn->prepare($query);
            $stmt->execute($params);
            
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
            
        } catch(Exception $e) {
            logAction("Error al obtener participantes: " . $e->getMessage(), 'ERROR');
            return [];
        }
    }
    
    public function getById($id) {
        try {
            $query = "SELECT * FROM " . $this->table_name . " WHERE id = ?";
            $stmt = $this->conn->prepare($query);
            $stmt->execute([$id]);
            
            return $stmt->fetch(PDO::FETCH_ASSOC);
            
        } catch(Exception $e) {
            logAction("Error al obtener participante: " . $e->getMessage(), 'ERROR');
            return null;
        }
    }
    
    public function create($data) {
        try {
            // Verificar si la cédula ya existe
            $query = "SELECT id FROM " . $this->table_name . " WHERE cedula = ?";
            $stmt = $this->conn->prepare($query);
            $stmt->execute([$data['cedula']]);
            
            if ($stmt->rowCount() > 0) {
                return ['success' => false, 'message' => 'Ya existe un participante con esta cédula'];
            }
            
            $query = "INSERT INTO " . $this->table_name . " 
                      (cedula, nombre, apellido, email, telefono, genero, fecha_nacimiento, 
                       direccion, ciudad, departamento, institucion, cargo, estado) 
                      VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
            
            $stmt = $this->conn->prepare($query);
            
            if ($stmt->execute([
                $data['cedula'],
                $data['nombre'],
                $data['apellido'],
                $data['email'] ?? null,
                $data['telefono'] ?? null,
                $data['genero'],
                $data['fecha_nacimiento'] ?? null,
                $data['direccion'] ?? null,
                $data['ciudad'] ?? null,
                $data['departamento'] ?? null,
                $data['institucion'] ?? null,
                $data['cargo'] ?? null,
                $data['estado'] ?? 'activo'
            ])) {
                $id = $this->conn->lastInsertId();
                logAction("Participante creado: " . $data['nombre'] . ' ' . $data['apellido'] . " (ID: $id)");
                return ['success' => true, 'message' => 'Participante creado exitosamente', 'id' => $id];
            }
            
            return ['success' => false, 'message' => 'Error al crear participante'];
            
        } catch(Exception $e) {
            logAction("Error al crear participante: " . $e->getMessage(), 'ERROR');
            return ['success' => false, 'message' => 'Error del sistema: ' . $e->getMessage()];
        }
    }
    
    public function update($id, $data) {
        try {
            // Verificar si la cédula ya existe en otro registro
            $query = "SELECT id FROM " . $this->table_name . " WHERE cedula = ? AND id != ?";
            $stmt = $this->conn->prepare($query);
            $stmt->execute([$data['cedula'], $id]);
            
            if ($stmt->rowCount() > 0) {
                return ['success' => false, 'message' => 'Ya existe otro participante con esta cédula'];
            }
            
            $query = "UPDATE " . $this->table_name . " 
                      SET cedula=?, nombre=?, apellido=?, email=?, telefono=?, genero=?, 
                          fecha_nacimiento=?, direccion=?, ciudad=?, departamento=?, 
                          institucion=?, cargo=?, estado=?
                      WHERE id=?";
            
            $stmt = $this->conn->prepare($query);
            
            if ($stmt->execute([
                $data['cedula'],
                $data['nombre'],
                $data['apellido'],
                $data['email'] ?? null,
                $data['telefono'] ?? null,
                $data['genero'],
                $data['fecha_nacimiento'] ?? null,
                $data['direccion'] ?? null,
                $data['ciudad'] ?? null,
                $data['departamento'] ?? null,
                $data['institucion'] ?? null,
                $data['cargo'] ?? null,
                $data['estado'] ?? 'activo',
                $id
            ])) {
                logAction("Participante actualizado: ID $id");
                return ['success' => true, 'message' => 'Participante actualizado exitosamente'];
            }
            
            return ['success' => false, 'message' => 'Error al actualizar participante'];
            
        } catch(Exception $e) {
            logAction("Error al actualizar participante: " . $e->getMessage(), 'ERROR');
            return ['success' => false, 'message' => 'Error del sistema: ' . $e->getMessage()];
        }
    }
    
    public function delete($id) {
        try {
            // Verificar si tiene matrículas activas
            $query = "SELECT COUNT(*) as count FROM matriculas WHERE participante_id = ? AND estado = 'activa'";
            $stmt = $this->conn->prepare($query);
            $stmt->execute([$id]);
            $result = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if ($result['count'] > 0) {
                return ['success' => false, 'message' => 'No se puede eliminar: el participante tiene matrículas activas'];
            }
            
            $query = "DELETE FROM " . $this->table_name . " WHERE id = ?";
            $stmt = $this->conn->prepare($query);
            
            if ($stmt->execute([$id])) {
                logAction("Participante eliminado: ID $id");
                return ['success' => true, 'message' => 'Participante eliminado exitosamente'];
            }
            
            return ['success' => false, 'message' => 'Error al eliminar participante'];
            
        } catch(Exception $e) {
            logAction("Error al eliminar participante: " . $e->getMessage(), 'ERROR');
            return ['success' => false, 'message' => 'Error del sistema: ' . $e->getMessage()];
        }
    }
    
    public function getCount($search = '') {
        try {
            $whereClause = '';
            $params = [];
            
            if (!empty($search)) {
                $whereClause = "WHERE cedula LIKE ? OR nombre LIKE ? OR apellido LIKE ? OR email LIKE ? OR institucion LIKE ?";
                $searchTerm = "%{$search}%";
                $params = [$searchTerm, $searchTerm, $searchTerm, $searchTerm, $searchTerm];
            }
            
            $query = "SELECT COUNT(*) as total FROM " . $this->table_name . " $whereClause";
            $stmt = $this->conn->prepare($query);
            $stmt->execute($params);
            
            $result = $stmt->fetch(PDO::FETCH_ASSOC);
            return $result['total'];
            
        } catch(Exception $e) {
            logAction("Error al contar participantes: " . $e->getMessage(), 'ERROR');
            return 0;
        }
    }
    
    public function getCertificados($participanteId) {
        try {
            $query = "SELECT c.*, cur.nombre as curso_nombre, cur.duracion_horas 
                      FROM certificados c
                      INNER JOIN matriculas m ON c.matricula_id = m.id
                      INNER JOIN cursos cur ON m.curso_id = cur.id
                      WHERE m.participante_id = ?
                      ORDER BY c.fecha_emision DESC";
            
            $stmt = $this->conn->prepare($query);
            $stmt->execute([$participanteId]);
            
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
            
        } catch(Exception $e) {
            logAction("Error al obtener certificados del participante: " . $e->getMessage(), 'ERROR');
            return [];
        }
    }
}
?>
