-- Base de datos completa para el sistema de certificados
CREATE DATABASE IF NOT EXISTS bomberos_certificados CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
USE bomberos_certificados;

-- Tabla de usuarios del sistema
CREATE TABLE usuarios (
    id INT PRIMARY KEY AUTO_INCREMENT,
    email VARCHAR(255) UNIQUE NOT NULL,
    password VARCHAR(255) NOT NULL,
    nombre VARCHAR(255) NOT NULL,
    apellido VARCHAR(255) NOT NULL,
    rol ENUM('admin', 'coordinador', 'instructor', 'secretaria') DEFAULT 'secretaria',
    estado ENUM('activo', 'inactivo') DEFAULT 'activo',
    fecha_creacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    fecha_actualizacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
);

-- Tabla de participantes
CREATE TABLE participantes (
    id INT PRIMARY KEY AUTO_INCREMENT,
    cedula VARCHAR(20) UNIQUE NOT NULL,
    nombre VARCHAR(255) NOT NULL,
    apellido VARCHAR(255) NOT NULL,
    email VARCHAR(255),
    telefono VARCHAR(20),
    genero ENUM('M', 'F') NOT NULL,
    fecha_nacimiento DATE,
    direccion TEXT,
    ciudad VARCHAR(100),
    departamento VARCHAR(100),
    institucion VARCHAR(255),
    cargo VARCHAR(255),
    fotografia VARCHAR(255),
    estado ENUM('activo', 'inactivo') DEFAULT 'activo',
    fecha_registro TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    fecha_actualizacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
);

-- Tabla de cursos
CREATE TABLE cursos (
    id INT PRIMARY KEY AUTO_INCREMENT,
    codigo VARCHAR(50) UNIQUE NOT NULL,
    nombre VARCHAR(255) NOT NULL,
    descripcion TEXT,
    tipo ENUM('capacitacion', 'entrenamiento', 'certificacion', 'diplomado') DEFAULT 'capacitacion',
    modalidad ENUM('presencial', 'virtual', 'mixta') DEFAULT 'presencial',
    duracion_horas INT NOT NULL,
    fecha_inicio DATE NOT NULL,
    fecha_fin DATE,
    instructor VARCHAR(255),
    lugar VARCHAR(255),
    cupo_maximo INT DEFAULT 30,
    costo DECIMAL(10,2) DEFAULT 0.00,
    contenido_tematico TEXT,
    objetivos TEXT,
    metodologia TEXT,
    evaluacion TEXT,
    requisitos TEXT,
    estado ENUM('programado', 'en_curso', 'finalizado', 'cancelado') DEFAULT 'programado',
    fecha_creacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    fecha_actualizacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
);

-- Tabla de matrículas
CREATE TABLE matriculas (
    id INT PRIMARY KEY AUTO_INCREMENT,
    participante_id INT NOT NULL,
    curso_id INT NOT NULL,
    fecha_matricula TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    estado ENUM('activa', 'cancelada', 'completada') DEFAULT 'activa',
    observaciones TEXT,
    FOREIGN KEY (participante_id) REFERENCES participantes(id) ON DELETE CASCADE,
    FOREIGN KEY (curso_id) REFERENCES cursos(id) ON DELETE CASCADE,
    UNIQUE KEY unique_matricula (participante_id, curso_id)
);

-- Tabla de calificaciones
CREATE TABLE calificaciones (
    id INT PRIMARY KEY AUTO_INCREMENT,
    matricula_id INT NOT NULL,
    nota_teorica DECIMAL(5,2) DEFAULT 0.00,
    nota_practica DECIMAL(5,2) DEFAULT 0.00,
    nota_final DECIMAL(5,2) GENERATED ALWAYS AS (
        CASE 
            WHEN nota_teorica > 0 AND nota_practica > 0 THEN (nota_teorica * 0.4 + nota_practica * 0.6)
            WHEN nota_teorica > 0 AND nota_practica = 0 THEN nota_teorica
            WHEN nota_teorica = 0 AND nota_practica > 0 THEN nota_practica
            ELSE 0
        END
    ) STORED,
    estado ENUM('aprobado', 'reprobado', 'pendiente') GENERATED ALWAYS AS (
        CASE 
            WHEN (nota_teorica * 0.4 + nota_practica * 0.6) >= 70 OR 
                 (nota_teorica >= 70 AND nota_practica = 0) OR 
                 (nota_practica >= 70 AND nota_teorica = 0) THEN 'aprobado'
            WHEN (nota_teorica > 0 OR nota_practica > 0) THEN 'reprobado'
            ELSE 'pendiente'
        END
    ) STORED,
    observaciones TEXT,
    fecha_calificacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    fecha_actualizacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (matricula_id) REFERENCES matriculas(id) ON DELETE CASCADE
);

-- Tabla de certificados
CREATE TABLE certificados (
    id INT PRIMARY KEY AUTO_INCREMENT,
    matricula_id INT NOT NULL,
    codigo VARCHAR(100) UNIQUE NOT NULL,
    fecha_emision TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    estado ENUM('borrador', 'emitido', 'revocado') DEFAULT 'borrador',
    archivo_pdf VARCHAR(255),
    hash_documento VARCHAR(255),
    qr_code VARCHAR(255),
    observaciones TEXT,
    fecha_actualizacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (matricula_id) REFERENCES matriculas(id) ON DELETE CASCADE
);

-- Tabla de firmas digitales
CREATE TABLE firmas (
    id INT PRIMARY KEY AUTO_INCREMENT,
    certificado_id INT NOT NULL,
    usuario_id INT NOT NULL,
    tipo_firma ENUM('coordinador', 'director', 'instructor') NOT NULL,
    nombre_firmante VARCHAR(255) NOT NULL,
    cargo_firmante VARCHAR(255) NOT NULL,
    firma_digital TEXT,
    hash_firma VARCHAR(255),
    fecha_firma TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    ip_address VARCHAR(45),
    estado ENUM('pendiente', 'firmado', 'rechazado') DEFAULT 'pendiente',
    FOREIGN KEY (certificado_id) REFERENCES certificados(id) ON DELETE CASCADE,
    FOREIGN KEY (usuario_id) REFERENCES usuarios(id) ON DELETE CASCADE
);

-- Tabla de logs del sistema
CREATE TABLE logs_sistema (
    id INT PRIMARY KEY AUTO_INCREMENT,
    usuario_id INT,
    accion VARCHAR(255) NOT NULL,
    tabla_afectada VARCHAR(100),
    registro_id INT,
    datos_anteriores JSON,
    datos_nuevos JSON,
    ip_address VARCHAR(45),
    user_agent TEXT,
    fecha_accion TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (usuario_id) REFERENCES usuarios(id) ON DELETE SET NULL
);

-- Insertar datos iniciales
INSERT INTO usuarios (email, password, nombre, apellido, rol) VALUES
('admin@esiboc.edu.co', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'Administrador', 'Sistema', 'admin'),
('coordinador@esiboc.edu.co', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'Carlos', 'Martínez', 'coordinador'),
('instructor@esiboc.edu.co', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'Laura', 'Gómez', 'instructor'),
('secretaria@esiboc.edu.co', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'Ana', 'Rodríguez', 'secretaria');

-- Insertar participantes de ejemplo
INSERT INTO participantes (cedula, nombre, apellido, email, telefono, genero, institucion, cargo) VALUES
('12345678', 'Juan Carlos', 'Pérez González', 'juan.perez@bomberos.gov.co', '3001234567', 'M', 'Bomberos Bogotá', 'Bombero'),
('87654321', 'María Elena', 'Rodríguez López', 'maria.rodriguez@bomberos.gov.co', '3009876543', 'F', 'Bomberos Medellín', 'Teniente'),
('11223344', 'Andrés Felipe', 'Martínez Silva', 'andres.martinez@bomberos.gov.co', '3005566778', 'M', 'Bomberos Cali', 'Capitán'),
('44332211', 'Carmen Lucía', 'García Torres', 'carmen.garcia@bomberos.gov.co', '3007788990', 'F', 'Bomberos Barranquilla', 'Bombero'),
('55667788', 'Luis Alberto', 'Hernández Ruiz', 'luis.hernandez@bomberos.gov.co', '3002233445', 'M', 'Bomberos Cartagena', 'Sargento');

-- Insertar cursos de ejemplo
INSERT INTO cursos (codigo, nombre, descripcion, tipo, modalidad, duracion_horas, fecha_inicio, fecha_fin, instructor, lugar, cupo_maximo, estado) VALUES
('TREC-2025-001', 'Técnicas de Rescate en Estructuras Colapsadas', 'Curso especializado en técnicas de búsqueda y rescate en estructuras colapsadas', 'certificacion', 'presencial', 40, '2025-02-01', '2025-02-05', 'Carlos Martínez', 'ESIBOC - Sede Principal', 25, 'programado'),
('PREV-2025-001', 'Prevención de Incendios Forestales', 'Capacitación en prevención y control de incendios forestales', 'capacitacion', 'mixta', 32, '2025-02-15', '2025-02-18', 'Laura Gómez', 'ESIBOC - Aula Virtual', 30, 'programado'),
('PRIM-2025-001', 'Primeros Auxilios Avanzados', 'Curso de primeros auxilios para personal de emergencias', 'entrenamiento', 'presencial', 24, '2025-03-01', '2025-03-03', 'Dr. Roberto Silva', 'ESIBOC - Laboratorio', 20, 'programado'),
('HMAT-2025-001', 'Manejo de Materiales Peligrosos', 'Capacitación en identificación y manejo de materiales peligrosos', 'certificacion', 'presencial', 48, '2025-03-15', '2025-03-20', 'Ing. Patricia López', 'ESIBOC - Campo de Entrenamiento', 15, 'programado');

-- Nota: La contraseña para todos los usuarios es "password123"
