"use client"

import { createContext, useContext, useEffect, useState, type ReactNode } from "react"
import { apiClient } from "@/lib/api"
import { useRouter } from "next/navigation"

interface User {
  id: string
  email: string
  nombre: string
  rol: string
  escuela_id?: string
}

interface AuthContextType {
  user: User | null
  login: (email: string, password: string) => Promise<{ success: boolean; error?: string }>
  logout: () => void
  loading: boolean
  isAuthenticated: boolean
}

const AuthContext = createContext<AuthContextType | undefined>(undefined)

export function AuthProvider({ children }: { children: ReactNode }) {
  const [user, setUser] = useState<User | null>(null)
  const [loading, setLoading] = useState(true)
  const router = useRouter()

  useEffect(() => {
    checkAuth()
  }, [])

  const checkAuth = async () => {
    const token = localStorage.getItem("auth_token")
    if (!token) {
      setLoading(false)
      return
    }

    apiClient.setToken(token)
    const response = await apiClient.verifyToken()

    if (response.success) {
      // Token válido, obtener datos del usuario del token
      const userData = parseTokenData(token)
      setUser(userData)
    } else {
      // Token inválido, limpiar
      localStorage.removeItem("auth_token")
      apiClient.removeToken()
    }

    setLoading(false)
  }

  const parseTokenData = (token: string): User | null => {
    try {
      const payload = token.split(".")[1]
      const decoded = JSON.parse(atob(payload))
      return {
        id: decoded.user_id,
        email: decoded.email,
        nombre: decoded.nombre || decoded.email,
        rol: decoded.rol,
        escuela_id: decoded.escuela_id,
      }
    } catch {
      return null
    }
  }

  const login = async (email: string, password: string) => {
    const response = await apiClient.login(email, password)

    if (response.success && response.data) {
      const { token, user: userData } = response.data
      apiClient.setToken(token)
      setUser(userData)
      return { success: true }
    }

    return {
      success: false,
      error: response.error || "Error al iniciar sesión",
    }
  }

  const logout = async () => {
    await apiClient.logout()
    setUser(null)
    router.push("/login")
  }

  return (
    <AuthContext.Provider
      value={{
        user,
        login,
        logout,
        loading,
        isAuthenticated: !!user,
      }}
    >
      {children}
    </AuthContext.Provider>
  )
}

export function useAuth() {
  const context = useContext(AuthContext)
  if (context === undefined) {
    throw new Error("useAuth must be used within an AuthProvider")
  }
  return context
}
