<?php
// Iniciar sesión
session_start();

// Incluir archivos de configuración
require_once 'config/config.php';
require_once 'config/Database.php';

// Incluir clases
require_once 'classes/Auth.php';
require_once 'classes/Participante.php';
require_once 'classes/Curso.php';

// Crear conexión a la base de datos
try {
    $database = new Database();
    $db = $database->getConnection();
} catch(Exception $e) {
    die("Error de conexión a la base de datos. Por favor, verifique la configuración.");
}

// Inicializar objetos
$auth = new Auth($db);
$participante = new Participante($db);
$curso = new Curso($db);

// Variables para mensajes
$message = '';
$messageType = '';

// Verificar autenticación
$user = null;
if(isset($_SESSION['user_id'])) {
    $user = $auth->getUserById($_SESSION['user_id']);
    if(!$user) {
        session_destroy();
        header("Location: " . $_SERVER['PHP_SELF']);
        exit;
    }
}

// Procesar acciones
if($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'] ?? '';
    
    switch($action) {
        case 'login':
            $email = sanitizeInput($_POST['email'] ?? '');
            $password = $_POST['password'] ?? '';
            
            if(empty($email) || empty($password)) {
                $message = 'Por favor complete todos los campos';
                $messageType = 'danger';
            } else {
                $result = $auth->login($email, $password);
                
                if($result['success']) {
                    $_SESSION['user_id'] = $result['user']['id'];
                    $_SESSION['user_name'] = $result['user']['nombre_completo'];
                    $_SESSION['user_email'] = $result['user']['email'];
                    $_SESSION['user_role'] = $result['user']['rol'];
                    
                    header("Location: " . $_SERVER['PHP_SELF']);
                    exit;
                } else {
                    $message = $result['message'];
                    $messageType = 'danger';
                }
            }
            break;
            
        case 'logout':
            session_destroy();
            header("Location: " . $_SERVER['PHP_SELF']);
            exit;
            break;
            
        case 'crear_participante':
            if(!$user) {
                $message = 'Debe iniciar sesión';
                $messageType = 'danger';
                break;
            }
            
            $data = [
                'cedula' => sanitizeInput($_POST['cedula'] ?? ''),
                'nombre' => sanitizeInput($_POST['nombre'] ?? ''),
                'apellido' => sanitizeInput($_POST['apellido'] ?? ''),
                'email' => sanitizeInput($_POST['email'] ?? ''),
                'telefono' => sanitizeInput($_POST['telefono'] ?? ''),
                'genero' => sanitizeInput($_POST['genero'] ?? ''),
                'fecha_nacimiento' => sanitizeInput($_POST['fecha_nacimiento'] ?? ''),
                'direccion' => sanitizeInput($_POST['direccion'] ?? ''),
                'ciudad' => sanitizeInput($_POST['ciudad'] ?? ''),
                'departamento' => sanitizeInput($_POST['departamento'] ?? ''),
                'institucion' => sanitizeInput($_POST['institucion'] ?? ''),
                'cargo' => sanitizeInput($_POST['cargo'] ?? '')
            ];
            
            $result = $participante->create($data);
            $message = $result['message'];
            $messageType = $result['success'] ? 'success' : 'danger';
            break;
            
        case 'crear_curso':
            if(!$user) {
                $message = 'Debe iniciar sesión';
                $messageType = 'danger';
                break;
            }
            
            $data = [
                'codigo' => sanitizeInput($_POST['codigo'] ?? ''),
                'nombre' => sanitizeInput($_POST['nombre'] ?? ''),
                'descripcion' => sanitizeInput($_POST['descripcion'] ?? ''),
                'tipo' => sanitizeInput($_POST['tipo'] ?? ''),
                'modalidad' => sanitizeInput($_POST['modalidad'] ?? ''),
                'duracion_horas' => intval($_POST['duracion_horas'] ?? 0),
                'fecha_inicio' => sanitizeInput($_POST['fecha_inicio'] ?? ''),
                'fecha_fin' => sanitizeInput($_POST['fecha_fin'] ?? ''),
                'instructor' => sanitizeInput($_POST['instructor'] ?? ''),
                'lugar' => sanitizeInput($_POST['lugar'] ?? ''),
                'cupo_maximo' => intval($_POST['cupo_maximo'] ?? 30),
                'costo' => floatval($_POST['costo'] ?? 0),
                'contenido_tematico' => sanitizeInput($_POST['contenido_tematico'] ?? ''),
                'objetivos' => sanitizeInput($_POST['objetivos'] ?? ''),
                'metodologia' => sanitizeInput($_POST['metodologia'] ?? ''),
                'evaluacion' => sanitizeInput($_POST['evaluacion'] ?? ''),
                'requisitos' => sanitizeInput($_POST['requisitos'] ?? ''),
                'estado' => sanitizeInput($_POST['estado'] ?? 'programado')
            ];
            
            // Generar código automáticamente si está vacío
            if(empty($data['codigo'])) {
                $data['codigo'] = $curso->generateCodigo();
            }
            
            $result = $curso->create($data);
            $message = $result['message'];
            $messageType = $result['success'] ? 'success' : 'danger';
            break;
    }
}

// Obtener datos para mostrar
$participantes_list = $participante->getAll(50);
$cursos_list = $curso->getAll(50);
$participantes_count = $participante->getCount();
$cursos_count = $curso->getCount();

// Verificación de certificado
$certificado_verificado = null;
if(isset($_GET['verificar']) && isset($_GET['codigo'])) {
    $codigo = sanitizeInput($_GET['codigo']);
    
    try {
        $query = "SELECT c.*, p.nombre as participante_nombre, p.apellido as participante_apellido, 
                         p.cedula as participante_cedula, cur.nombre as curso_nombre, 
                         cur.duracion_horas, cur.fecha_inicio, cur.fecha_fin 
                  FROM certificados c
                  INNER JOIN matriculas m ON c.matricula_id = m.id
                  INNER JOIN participantes p ON m.participante_id = p.id
                  INNER JOIN cursos cur ON m.curso_id = cur.id
                  WHERE c.codigo = ? AND c.estado = 'emitido'";
        
        $stmt = $db->prepare($query);
        $stmt->execute([$codigo]);
        $certificado_verificado = $stmt->fetch(PDO::FETCH_ASSOC);
        
    } catch(Exception $e) {
        logAction("Error al verificar certificado: " . $e->getMessage(), 'ERROR');
    }
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo APP_NAME; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.0/font/bootstrap-icons.css">
    <style>
        body {
            padding-top: 76px;
            background-color: #f8f9fa;
        }
        .navbar-brand {
            font-weight: bold;
        }
        .card {
            box-shadow: 0 0.125rem 0.25rem rgba(0, 0, 0, 0.075);
            border: 1px solid rgba(0, 0, 0, 0.125);
        }
        .card-dashboard {
            transition: transform 0.2s;
        }
        .card-dashboard:hover {
            transform: translateY(-2px);
        }
        .table th {
            background-color: #f8f9fa;
            border-top: none;
        }
        .btn-group-sm > .btn, .btn-sm {
            padding: 0.25rem 0.5rem;
            font-size: 0.875rem;
        }
        .verification-result {
            border-radius: 0.5rem;
            padding: 1.5rem;
            margin-top: 1rem;
        }
        .verification-success {
            background-color: #d1e7dd;
            border: 1px solid #badbcc;
            color: #0f5132;
        }
        .verification-error {
            background-color: #f8d7da;
            border: 1px solid #f5c2c7;
            color: #842029;
        }
        .footer {
            background-color: #343a40;
            color: white;
            margin-top: 3rem;
        }
        .nav-tabs .nav-link.active {
            background-color: #fff;
            border-color: #dee2e6 #dee2e6 #fff;
        }
        .form-label {
            font-weight: 500;
        }
        .required {
            color: #dc3545;
        }
    </style>
</head>
<body>
    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg navbar-dark bg-danger fixed-top">
        <div class="container">
            <a class="navbar-brand" href="#dashboard">
                <i class="bi bi-fire"></i> <?php echo APP_NAME; ?>
            </a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav me-auto">
                    <?php if($user): ?>
                    <li class="nav-item">
                        <a class="nav-link" href="#dashboard">
                            <i class="bi bi-speedometer2"></i> Dashboard
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="#participantes">
                            <i class="bi bi-people"></i> Participantes
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="#cursos">
                            <i class="bi bi-book"></i> Cursos
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="#certificados">
                            <i class="bi bi-award"></i> Certificados
                        </a>
                    </li>
                    <?php endif; ?>
                    <li class="nav-item">
                        <a class="nav-link" href="#verificar">
                            <i class="bi bi-check-circle"></i> Verificar
                        </a>
                    </li>
                </ul>
                <div class="d-flex">
                    <?php if($user): ?>
                        <div class="dropdown">
                            <button class="btn btn-light dropdown-toggle" type="button" data-bs-toggle="dropdown">
                                <i class="bi bi-person-circle"></i> <?php echo htmlspecialchars($user['nombre'] . ' ' . $user['apellido']); ?>
                            </button>
                            <ul class="dropdown-menu dropdown-menu-end">
                                <li><span class="dropdown-item-text"><?php echo htmlspecialchars($user['email']); ?></span></li>
                                <li><span class="dropdown-item-text">Rol: <?php echo ucfirst($user['rol']); ?></span></li>
                                <li><hr class="dropdown-divider"></li>
                                <li>
                                    <form method="post" class="d-inline">
                                        <input type="hidden" name="action" value="logout">
                                        <button type="submit" class="dropdown-item">
                                            <i class="bi bi-box-arrow-right"></i> Cerrar Sesión
                                        </button>
                                    </form>
                                </li>
                            </ul>
                        </div>
                    <?php else: ?>
                        <button type="button" class="btn btn-light" data-bs-toggle="modal" data-bs-target="#loginModal">
                            <i class="bi bi-box-arrow-in-right"></i> Iniciar Sesión
                        </button>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </nav>

    <!-- Mensajes -->
    <?php if($message): ?>
    <div class="container mt-3">
        <div class="alert alert-<?php echo $messageType; ?> alert-dismissible fade show" role="alert">
            <?php echo htmlspecialchars($message); ?>
            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
        </div>
    </div>
    <?php endif; ?>

    <!-- Contenido Principal -->
    <div class="container py-4">
        
        <!-- Dashboard -->
        <section id="dashboard" class="mb-5">
            <div class="row">
                <div class="col-12">
                    <h2 class="mb-4">
                        <i class="bi bi-speedometer2"></i> Panel de Control
                        <?php if($user): ?>
                            <small class="text-muted">- Bienvenido, <?php echo htmlspecialchars($user['nombre']); ?></small>
                        <?php endif; ?>
                    </h2>
                </div>
            </div>
            
            <div class="row">
                <div class="col-md-4 mb-4">
                    <div class="card card-dashboard border-primary h-100">
                        <div class="card-body text-center">
                            <i class="bi bi-people-fill text-primary" style="font-size: 3rem;"></i>
                            <h3 class="mt-3 mb-1"><?php echo number_format($participantes_count); ?></h3>
                            <h5 class="card-title">Participantes</h5>
                            <p class="card-text text-muted">Bomberos y personal registrado</p>
                            <?php if($user): ?>
                            <a href="#participantes" class="btn btn-primary btn-sm">
                                <i class="bi bi-arrow-right"></i> Gestionar
                            </a>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
                
                <div class="col-md-4 mb-4">
                    <div class="card card-dashboard border-success h-100">
                        <div class="card-body text-center">
                            <i class="bi bi-book-fill text-success" style="font-size: 3rem;"></i>
                            <h3 class="mt-3 mb-1"><?php echo number_format($cursos_count); ?></h3>
                            <h5 class="card-title">Cursos</h5>
                            <p class="card-text text-muted">Capacitaciones disponibles</p>
                            <?php if($user): ?>
                            <a href="#cursos" class="btn btn-success btn-sm">
                                <i class="bi bi-arrow-right"></i> Gestionar
                            </a>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
                
                <div class="col-md-4 mb-4">
                    <div class="card card-dashboard border-warning h-100">
                        <div class="card-body text-center">
                            <i class="bi bi-award-fill text-warning" style="font-size: 3rem;"></i>
                            <h3 class="mt-3 mb-1">0</h3>
                            <h5 class="card-title">Certificados</h5>
                            <p class="card-text text-muted">Certificados emitidos</p>
                            <?php if($user): ?>
                            <a href="#certificados" class="btn btn-warning btn-sm">
                                <i class="bi bi-arrow-right"></i> Gestionar
                            </a>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </section>

        <?php if($user): ?>
        <!-- Participantes -->
        <section id="participantes" class="mb-5">
            <div class="card">
                <div class="card-header bg-primary text-white">
                    <h3 class="mb-0">
                        <i class="bi bi-people-fill"></i> Gestión de Participantes
                    </h3>
                </div>
                <div class="card-body">
                    <ul class="nav nav-tabs mb-4" id="participantesTab" role="tablist">
                        <li class="nav-item" role="presentation">
                            <button class="nav-link active" id="lista-participantes-tab" data-bs-toggle="tab" 
                                    data-bs-target="#lista-participantes" type="button" role="tab">
                                <i class="bi bi-list"></i> Lista de Participantes
                            </button>
                        </li>
                        <li class="nav-item" role="presentation">
                            <button class="nav-link" id="nuevo-participante-tab" data-bs-toggle="tab" 
                                    data-bs-target="#nuevo-participante" type="button" role="tab">
                                <i class="bi bi-plus-circle"></i> Nuevo Participante
                            </button>
                        </li>
                    </ul>
                    
                    <div class="tab-content" id="participantesTabContent">
                        <!-- Lista de Participantes -->
                        <div class="tab-pane fade show active" id="lista-participantes" role="tabpanel">
                            <div class="table-responsive">
                                <table class="table table-striped table-hover">
                                    <thead>
                                        <tr>
                                            <th>Cédula</th>
                                            <th>Nombre Completo</th>
                                            <th>Email</th>
                                            <th>Teléfono</th>
                                            <th>Institución</th>
                                            <th>Estado</th>
                                            <th>Acciones</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php if(count($participantes_list) > 0): ?>
                                            <?php foreach($participantes_list as $item): ?>
                                                <tr>
                                                    <td><?php echo htmlspecialchars($item['cedula']); ?></td>
                                                    <td><?php echo htmlspecialchars($item['nombre'] . ' ' . $item['apellido']); ?></td>
                                                    <td><?php echo htmlspecialchars($item['email'] ?? ''); ?></td>
                                                    <td><?php echo htmlspecialchars($item['telefono'] ?? ''); ?></td>
                                                    <td><?php echo htmlspecialchars($item['institucion'] ?? ''); ?></td>
                                                    <td>
                                                        <span class="badge bg-<?php echo $item['estado'] == 'activo' ? 'success' : 'secondary'; ?>">
                                                            <?php echo ucfirst($item['estado']); ?>
                                                        </span>
                                                    </td>
                                                    <td>
                                                        <div class="btn-group btn-group-sm" role="group">
                                                            <button class="btn btn-outline-info" title="Ver detalles">
                                                                <i class="bi bi-eye"></i>
                                                            </button>
                                                            <button class="btn btn-outline-warning" title="Editar">
                                                                <i class="bi bi-pencil"></i>
                                                            </button>
                                                            <button class="btn btn-outline-danger" title="Eliminar">
                                                                <i class="bi bi-trash"></i>
                                                            </button>
                                                        </div>
                                                    </td>
                                                </tr>
                                            <?php endforeach; ?>
                                        <?php else: ?>
                                            <tr>
                                                <td colspan="6" class="text-center text-muted py-4">
                                                    <i class="bi bi-inbox"></i> No hay participantes registrados
                                                </td>
                                            </tr>
                                        <?php endif; ?>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                        
                        <!-- Nuevo Participante -->
                        <div class="tab-pane fade" id="nuevo-participante" role="tabpanel">
                            <form method="post" action="">
                                <input type="hidden" name="action" value="crear_participante">
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="cedula" class="form-label">
                                            Cédula <span class="required">*</span>
                                        </label>
                                        <input type="text" class="form-control" id="cedula" name="cedula" required>
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label for="genero" class="form-label">
                                            Género <span class="required">*</span>
                                        </label>
                                        <select class="form-select" id="genero" name="genero" required>
                                            <option value="">Seleccione...</option>
                                            <option value="M">Masculino</option>
                                            <option value="F">Femenino</option>
                                        </select>
                                    </div>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="nombre" class="form-label">
                                            Nombre <span class="required">*</span>
                                        </label>
                                        <input type="text" class="form-control" id="nombre" name="nombre" required>
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label for="apellido" class="form-label">
                                            Apellido <span class="required">*</span>
                                        </label>
                                        <input type="text" class="form-control" id="apellido" name="apellido" required>
                                    </div>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="email" class="form-label">Email</label>
                                        <input type="email" class="form-control" id="email" name="email">
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label for="telefono" class="form-label">Teléfono</label>
                                        <input type="text" class="form-control" id="telefono" name="telefono">
                                    </div>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="fecha_nacimiento" class="form-label">Fecha de Nacimiento</label>
                                        <input type="date" class="form-control" id="fecha_nacimiento" name="fecha_nacimiento">
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label for="ciudad" class="form-label">Ciudad</label>
                                        <input type="text" class="form-control" id="ciudad" name="ciudad">
                                    </div>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="institucion" class="form-label">Institución</label>
                                        <input type="text" class="form-control" id="institucion" name="institucion" 
                                               placeholder="Ej: Bomberos Bogotá">
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label for="cargo" class="form-label">Cargo</label>
                                        <input type="text" class="form-control" id="cargo" name="cargo" 
                                               placeholder="Ej: Bombero, Teniente, Capitán">
                                    </div>
                                </div>
                                
                                <div class="mb-3">
                                    <label for="direccion" class="form-label">Dirección</label>
                                    <textarea class="form-control" id="direccion" name="direccion" rows="2"></textarea>
                                </div>
                                
                                <div class="text-end">
                                    <button type="submit" class="btn btn-primary">
                                        <i class="bi bi-save"></i> Guardar Participante
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </section>

        <!-- Cursos -->
        <section id="cursos" class="mb-5">
            <div class="card">
                <div class="card-header bg-success text-white">
                    <h3 class="mb-0">
                        <i class="bi bi-book-fill"></i> Gestión de Cursos
                    </h3>
                </div>
                <div class="card-body">
                    <ul class="nav nav-tabs mb-4" id="cursosTab" role="tablist">
                        <li class="nav-item" role="presentation">
                            <button class="nav-link active" id="lista-cursos-tab" data-bs-toggle="tab" 
                                    data-bs-target="#lista-cursos" type="button" role="tab">
                                <i class="bi bi-list"></i> Lista de Cursos
                            </button>
                        </li>
                        <li class="nav-item" role="presentation">
                            <button class="nav-link" id="nuevo-curso-tab" data-bs-toggle="tab" 
                                    data-bs-target="#nuevo-curso" type="button" role="tab">
                                <i class="bi bi-plus-circle"></i> Nuevo Curso
                            </button>
                        </li>
                    </ul>
                    
                    <div class="tab-content" id="cursosTabContent">
                        <!-- Lista de Cursos -->
                        <div class="tab-pane fade show active" id="lista-cursos" role="tabpanel">
                            <div class="table-responsive">
                                <table class="table table-striped table-hover">
                                    <thead>
                                        <tr>
                                            <th>Código</th>
                                            <th>Nombre</th>
                                            <th>Tipo</th>
                                            <th>Modalidad</th>
                                            <th>Duración</th>
                                            <th>Fecha Inicio</th>
                                            <th>Estado</th>
                                            <th>Acciones</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php if(count($cursos_list) > 0): ?>
                                            <?php foreach($cursos_list as $item): ?>
                                                <tr>
                                                    <td><code><?php echo htmlspecialchars($item['codigo']); ?></code></td>
                                                    <td><?php echo htmlspecialchars($item['nombre']); ?></td>
                                                    <td>
                                                        <span class="badge bg-info">
                                                            <?php echo ucfirst($item['tipo']); ?>
                                                        </span>
                                                    </td>
                                                    <td><?php echo ucfirst($item['modalidad']); ?></td>
                                                    <td><?php echo $item['duracion_horas']; ?> horas</td>
                                                    <td><?php echo date('d/m/Y', strtotime($item['fecha_inicio'])); ?></td>
                                                    <td>
                                                        <span class="badge bg-<?php 
                                                            echo $item['estado'] == 'programado' ? 'primary' : 
                                                                ($item['estado'] == 'en_curso' ? 'warning' : 
                                                                ($item['estado'] == 'finalizado' ? 'success' : 'secondary')); 
                                                        ?>">
                                                            <?php echo ucfirst(str_replace('_', ' ', $item['estado'])); ?>
                                                        </span>
                                                    </td>
                                                    <td>
                                                        <div class="btn-group btn-group-sm" role="group">
                                                            <button class="btn btn-outline-info" title="Ver detalles">
                                                                <i class="bi bi-eye"></i>
                                                            </button>
                                                            <button class="btn btn-outline-warning" title="Editar">
                                                                <i class="bi bi-pencil"></i>
                                                            </button>
                                                            <button class="btn btn-outline-primary" title="Matrículas">
                                                                <i class="bi bi-people"></i>
                                                            </button>
                                                        </div>
                                                    </td>
                                                </tr>
                                            <?php endforeach; ?>
                                        <?php else: ?>
                                            <tr>
                                                <td colspan="8" class="text-center text-muted py-4">
                                                    <i class="bi bi-inbox"></i> No hay cursos registrados
                                                </td>
                                            </tr>
                                        <?php endif; ?>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                        
                        <!-- Nuevo Curso -->
                        <div class="tab-pane fade" id="nuevo-curso" role="tabpanel">
                            <form method="post" action="">
                                <input type="hidden" name="action" value="crear_curso">
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="codigo" class="form-label">
                                            Código del Curso <span class="required">*</span>
                                        </label>
                                        <input type="text" class="form-control" id="codigo" name="codigo" 
                                               placeholder="Se generará automáticamente si se deja vacío">
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label for="tipo" class="form-label">
                                            Tipo <span class="required">*</span>
                                        </label>
                                        <select class="form-select" id="tipo" name="tipo" required>
                                            <option value="">Seleccione...</option>
                                            <option value="capacitacion">Capacitación</option>
                                            <option value="entrenamiento">Entrenamiento</option>
                                            <option value="certificacion">Certificación</option>
                                            <option value="diplomado">Diplomado</option>
                                        </select>
                                    </div>
                                </div>
                                
                                <div class="mb-3">
                                    <label for="nombre" class="form-label">
                                        Nombre del Curso <span class="required">*</span>
                                    </label>
                                    <input type="text" class="form-control" id="nombre" name="nombre" required>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="modalidad" class="form-label">
                                            Modalidad <span class="required">*</span>
                                        </label>
                                        <select class="form-select" id="modalidad" name="modalidad" required>
                                            <option value="">Seleccione...</option>
                                            <option value="presencial">Presencial</option>
                                            <option value="virtual">Virtual</option>
                                            <option value="mixta">Mixta</option>
                                        </select>
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label for="duracion_horas" class="form-label">
                                            Duración (horas) <span class="required">*</span>
                                        </label>
                                        <input type="number" class="form-control" id="duracion_horas" name="duracion_horas" 
                                               min="1" required>
                                    </div>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="fecha_inicio" class="form-label">
                                            Fecha Inicio <span class="required">*</span>
                                        </label>
                                        <input type="date" class="form-control" id="fecha_inicio" name="fecha_inicio" required>
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label for="fecha_fin" class="form-label">Fecha Fin</label>
                                        <input type="date" class="form-control" id="fecha_fin" name="fecha_fin">
                                    </div>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label for="instructor" class="form-label">Instructor</label>
                                        <input type="text" class="form-control" id="instructor" name="instructor">
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label for="lugar" class="form-label">Lugar</label>
                                        <input type="text" class="form-control" id="lugar" name="lugar">
                                    </div>
                                </div>
                                
                                <div class="row">
                                    <div class="col-md-4 mb-3">
                                        <label for="cupo_maximo" class="form-label">Cupo Máximo</label>
                                        <input type="number" class="form-control" id="cupo_maximo" name="cupo_maximo" 
                                               value="30" min="1">
                                    </div>
                                    
                                    <div class="col-md-4 mb-3">
                                        <label for="costo" class="form-label">Costo</label>
                                        <input type="number" class="form-control" id="costo" name="costo" 
                                               value="0" min="0" step="0.01">
                                    </div>
                                    
                                    <div class="col-md-4 mb-3">
                                        <label for="estado" class="form-label">Estado</label>
                                        <select class="form-select" id="estado" name="estado">
                                            <option value="programado">Programado</option>
                                            <option value="en_curso">En Curso</option>
                                            <option value="finalizado">Finalizado</option>
                                            <option value="cancelado">Cancelado</option>
                                        </select>
                                    </div>
                                </div>
                                
                                <div class="mb-3">
                                    <label for="descripcion" class="form-label">Descripción</label>
                                    <textarea class="form-control" id="descripcion" name="descripcion" rows="3"></textarea>
                                </div>
                                
                                <div class="text-end">
                                    <button type="submit" class="btn btn-success">
                                        <i class="bi bi-save"></i> Guardar Curso
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </section>

        <!-- Certificados -->
        <section id="certificados" class="mb-5">
            <div class="card">
                <div class="card-header bg-warning text-dark">
                    <h3 class="mb-0">
                        <i class="bi bi-award-fill"></i> Gestión de Certificados
                    </h3>
                </div>
                <div class="card-body">
                    <div class="alert alert-info">
                        <i class="bi bi-info-circle"></i> 
                        <strong>Próximamente:</strong> Módulo de generación y gestión de certificados en desarrollo.
                    </div>
                </div>
            </div>
        </section>
        <?php endif; ?>

        <!-- Verificar Certificado -->
        <section id="verificar" class="mb-5">
            <div class="card">
                <div class="card-header bg-info text-white">
                    <h3 class="mb-0">
                        <i class="bi bi-check-circle"></i> Verificar Certificado
                    </h3>
                </div>
                <div class="card-body">
                    <div class="row">
                        <div class="col-md-8 mx-auto">
                            <form method="get" action="#verificar">
                                <input type="hidden" name="verificar" value="1">
                                
                                <div class="mb-3">
                                    <label for="codigo" class="form-label">Código de Certificado</label>
                                    <input type="text" class="form-control form-control-lg" id="codigo" name="codigo" 
                                           placeholder="Ej: CERT-2025-0001" required 
                                           value="<?php echo htmlspecialchars($_GET['codigo'] ?? ''); ?>">
                                </div>
                                
                                <div class="text-center">
                                    <button type="submit" class="btn btn-info btn-lg">
                                        <i class="bi bi-search"></i> Verificar Certificado
                                    </button>
                                </div>
                            </form>
                            
                            <?php if(isset($_GET['verificar']) && isset($_GET['codigo'])): ?>
                                <?php if($certificado_verificado): ?>
                                    <div class="verification-result verification-success">
                                        <h4 class="text-success mb-3">
                                            <i class="bi bi-check-circle-fill"></i> Certificado Válido
                                        </h4>
                                        <hr>
                                        <div class="row">
                                            <div class="col-md-6">
                                                <p><strong>Código:</strong> 
                                                   <code><?php echo htmlspecialchars($certificado_verificado['codigo']); ?></code>
                                                </p>
                                                <p><strong>Participante:</strong> 
                                                   <?php echo htmlspecialchars($certificado_verificado['participante_nombre'] . ' ' . $certificado_verificado['participante_apellido']); ?>
                                                </p>
                                                <p><strong>Documento:</strong> 
                                                   <?php echo htmlspecialchars($certificado_verificado['participante_cedula']); ?>
                                                </p>
                                            </div>
                                            <div class="col-md-6">
                                                <p><strong>Curso:</strong> 
                                                   <?php echo htmlspecialchars($certificado_verificado['curso_nombre']); ?>
                                                </p>
                                                <p><strong>Duración:</strong> 
                                                   <?php echo $certificado_verificado['duracion_horas']; ?> horas
                                                </p>
                                                <p><strong>Fecha Emisión:</strong> 
                                                   <?php echo date('d/m/Y', strtotime($certificado_verificado['fecha_emision'])); ?>
                                                </p>
                                            </div>
                                        </div>
                                    </div>
                                <?php else: ?>
                                    <div class="verification-result verification-error">
                                        <h4 class="text-danger mb-3">
                                            <i class="bi bi-x-circle-fill"></i> Certificado No Válido
                                        </h4>
                                        <p>El código <code><?php echo htmlspecialchars($_GET['codigo']); ?></code> 
                                           no corresponde a ningún certificado registrado en el sistema.</p>
                                        <p class="mb-0">Por favor, verifique el código e intente nuevamente.</p>
                                    </div>
                                <?php endif; ?>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </section>
    </div>

    <!-- Footer -->
    <footer class="footer py-4">
        <div class="container">
            <div class="row">
                <div class="col-md-6">
                    <h5>Escuela Internacional de Bomberos del Oriente Colombiano</h5>
                    <p class="mb-0">Sistema de Gestión de Certificados</p>
                </div>
                <div class="col-md-6 text-md-end">
                    <p class="mb-1">Versión <?php echo APP_VERSION; ?></p>
                    <p class="mb-0">&copy; <?php echo date('Y'); ?> ESIBOC. Todos los derechos reservados.</p>
                </div>
            </div>
        </div>
    </footer>

    <!-- Login Modal -->
    <div class="modal fade" id="loginModal" tabindex="-1" aria-labelledby="loginModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header bg-danger text-white">
                    <h5 class="modal-title" id="loginModalLabel">
                        <i class="bi bi-box-arrow-in-right"></i> Iniciar Sesión
                    </h5>
                    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="login">
                        
                        <div class="mb-3">
                            <label for="email" class="form-label">Correo Electrónico</label>
                            <input type="email" class="form-control" id="email" name="email" required>
                        </div>
                        
                        <div class="mb-3">
                            <label for="password" class="form-label">Contraseña</label>
                            <input type="password" class="form-control" id="password" name="password" required>
                        </div>
                        
                        <div class="alert alert-info">
                            <strong>Credenciales de prueba:</strong><br>
                            <small>
                                <strong>Admin:</strong> admin@esiboc.edu.co / password123<br>
                                <strong>Coordinador:</strong> coordinador@esiboc.edu.co / password123<br>
                                <strong>Instructor:</strong> instructor@esiboc.edu.co / password123<br>
                                <strong>Secretaria:</strong> secretaria@esiboc.edu.co / password123
                            </small>
                        </div>
                        
                        <div class="text-end">
                            <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancelar</button>
                            <button type="submit" class="btn btn-danger">Iniciar Sesión</button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>

    <!-- Scripts -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Smooth scrolling para los enlaces del navbar
        document.querySelectorAll('a[href^="#"]').forEach(anchor => {
            anchor.addEventListener('click', function (e) {
                e.preventDefault();
                const target = document.querySelector(this.getAttribute('href'));
                if (target) {
                    target.scrollIntoView({
                        behavior: 'smooth',
                        block: 'start'
                    });
                }
            });
        });

        // Auto-dismiss alerts después de 5 segundos
        setTimeout(function() {
            const alerts = document.querySelectorAll('.alert-dismissible');
            alerts.forEach(function(alert) {
                const bsAlert = new bootstrap.Alert(alert);
                bsAlert.close();
            });
        }, 5000);

        // Validación de formularios
        (function() {
            'use strict';
            window.addEventListener('load', function() {
                const forms = document.getElementsByClassName('needs-validation');
                Array.prototype.filter.call(forms, function(form) {
                    form.addEventListener('submit', function(event) {
                        if (form.checkValidity() === false) {
                            event.preventDefault();
                            event.stopPropagation();
                        }
                        form.classList.add('was-validated');
                    }, false);
                });
            }, false);
        })();
    </script>
</body>
</html>
