const API_BASE_URL = process.env.NEXT_PUBLIC_API_URL || "http://localhost/bomberos-backend/api"

interface ApiResponse<T = any> {
  success: boolean
  data?: T
  message?: string
  error?: string
}

class ApiClient {
  private baseURL: string
  private token: string | null = null

  constructor(baseURL: string) {
    this.baseURL = baseURL
    this.token = typeof window !== "undefined" ? localStorage.getItem("auth_token") : null
  }

  private async request<T>(endpoint: string, options: RequestInit = {}): Promise<ApiResponse<T>> {
    const url = `${this.baseURL}${endpoint}`

    const headers: HeadersInit = {
      "Content-Type": "application/json",
      ...options.headers,
    }

    if (this.token) {
      headers.Authorization = `Bearer ${this.token}`
    }

    try {
      const response = await fetch(url, {
        ...options,
        headers,
      })

      const data = await response.json()

      if (!response.ok) {
        return {
          success: false,
          error: data.message || "Error en la petición",
        }
      }

      return {
        success: true,
        data,
      }
    } catch (error) {
      return {
        success: false,
        error: error instanceof Error ? error.message : "Error de conexión",
      }
    }
  }

  setToken(token: string) {
    this.token = token
    if (typeof window !== "undefined") {
      localStorage.setItem("auth_token", token)
    }
  }

  removeToken() {
    this.token = null
    if (typeof window !== "undefined") {
      localStorage.removeItem("auth_token")
    }
  }

  // Auth endpoints
  async login(email: string, password: string) {
    return this.request("/auth.php", {
      method: "POST",
      body: JSON.stringify({
        action: "login",
        email,
        password,
      }),
    })
  }

  async logout() {
    const response = await this.request("/auth.php", {
      method: "POST",
      body: JSON.stringify({
        action: "logout",
      }),
    })
    this.removeToken()
    return response
  }

  async verifyToken() {
    return this.request("/auth.php", {
      method: "POST",
      body: JSON.stringify({
        action: "verify_token",
      }),
    })
  }

  // Participantes endpoints
  async getParticipantes() {
    return this.request("/participantes.php")
  }

  async getParticipante(id: string) {
    return this.request(`/participantes.php?id=${id}`)
  }

  async createParticipante(data: any) {
    return this.request("/participantes.php", {
      method: "POST",
      body: JSON.stringify(data),
    })
  }

  async updateParticipante(data: any) {
    return this.request("/participantes.php", {
      method: "PUT",
      body: JSON.stringify(data),
    })
  }

  async deleteParticipante(id: string) {
    return this.request(`/participantes.php?id=${id}`, {
      method: "DELETE",
    })
  }

  // Cursos endpoints
  async getCursos() {
    return this.request("/cursos.php")
  }

  async getCurso(id: string) {
    return this.request(`/cursos.php?id=${id}`)
  }

  async createCurso(data: any) {
    return this.request("/cursos.php", {
      method: "POST",
      body: JSON.stringify(data),
    })
  }

  async updateCurso(data: any) {
    return this.request("/cursos.php", {
      method: "PUT",
      body: JSON.stringify(data),
    })
  }

  // Certificados endpoints
  async getCertificados() {
    return this.request("/certificados.php")
  }

  async verificarCertificado(codigo: string) {
    return this.request(`/certificados.php?action=verificar&codigo=${codigo}`)
  }

  async generarCertificados(data: any) {
    return this.request("/certificados.php", {
      method: "POST",
      body: JSON.stringify({
        action: "generar",
        ...data,
      }),
    })
  }

  async firmarCertificado(data: any) {
    return this.request("/certificados.php", {
      method: "POST",
      body: JSON.stringify({
        action: "firmar",
        ...data,
      }),
    })
  }

  // Usuarios endpoints
  async getUsuarios() {
    return this.request("/usuarios.php")
  }

  async createUsuario(data: any) {
    return this.request("/usuarios.php", {
      method: "POST",
      body: JSON.stringify(data),
    })
  }

  async updateUsuario(data: any) {
    return this.request("/usuarios.php", {
      method: "PUT",
      body: JSON.stringify(data),
    })
  }

  // Matrículas endpoints
  async getMatriculas(cursoId?: string) {
    const url = cursoId ? `/matriculas.php?curso_id=${cursoId}` : "/matriculas.php"
    return this.request(url)
  }

  async matricularParticipantes(data: any) {
    return this.request("/matriculas.php", {
      method: "POST",
      body: JSON.stringify(data),
    })
  }

  // Calificaciones endpoints
  async getCalificaciones(cursoId: string) {
    return this.request(`/calificaciones.php?curso_id=${cursoId}`)
  }

  async updateCalificacion(data: any) {
    return this.request("/calificaciones.php", {
      method: "PUT",
      body: JSON.stringify(data),
    })
  }

  // Reportes endpoints
  async generarReporte(data: any) {
    return this.request("/reportes.php", {
      method: "POST",
      body: JSON.stringify(data),
    })
  }

  // Upload de archivos
  async uploadFile(file: File, type: string) {
    const formData = new FormData()
    formData.append("file", file)
    formData.append("type", type)

    const headers: HeadersInit = {}
    if (this.token) {
      headers.Authorization = `Bearer ${this.token}`
    }

    try {
      const response = await fetch(`${this.baseURL}/upload.php`, {
        method: "POST",
        headers,
        body: formData,
      })

      const data = await response.json()

      if (!response.ok) {
        return {
          success: false,
          error: data.message || "Error al subir archivo",
        }
      }

      return {
        success: true,
        data,
      }
    } catch (error) {
      return {
        success: false,
        error: error instanceof Error ? error.message : "Error de conexión",
      }
    }
  }
}

export const apiClient = new ApiClient(API_BASE_URL)
export default apiClient
